@@ -220,13 +220,69 @@ void ArchaeoLines::init()
 	Q_ASSERT(customDeclination1Line);
 	Q_ASSERT(customDeclination2Line);
 
+	connect(this, SIGNAL(equinoxColorChanged(Vec3f)),                equinoxLine                 , SLOT(setColor(Vec3f)));
+	connect(this, SIGNAL(solsticesColorChanged(Vec3f)),              northernSolsticeLine        , SLOT(setColor(Vec3f)));
+	connect(this, SIGNAL(solsticesColorChanged(Vec3f)),              southernSolsticeLine        , SLOT(setColor(Vec3f)));
+	connect(this, SIGNAL(crossquartersColorChanged(Vec3f)),          northernCrossquarterLine    , SLOT(setColor(Vec3f)));
+	connect(this, SIGNAL(crossquartersColorChanged(Vec3f)),          southernCrossquarterLine    , SLOT(setColor(Vec3f)));
+	connect(this, SIGNAL(majorStandstillColorChanged(Vec3f)),        northernMajorStandstillLine0, SLOT(setColor(Vec3f)));
+	connect(this, SIGNAL(majorStandstillColorChanged(Vec3f)),        northernMajorStandstillLine1, SLOT(setColor(Vec3f)));
+	connect(this, SIGNAL(majorStandstillColorChanged(Vec3f)),        southernMajorStandstillLine6, SLOT(setColor(Vec3f)));
+	connect(this, SIGNAL(majorStandstillColorChanged(Vec3f)),        southernMajorStandstillLine7, SLOT(setColor(Vec3f)));
+	connect(this, SIGNAL(minorStandstillColorChanged(Vec3f)),        northernMinorStandstillLine2, SLOT(setColor(Vec3f)));
+	connect(this, SIGNAL(minorStandstillColorChanged(Vec3f)),        northernMinorStandstillLine3, SLOT(setColor(Vec3f)));
+	connect(this, SIGNAL(minorStandstillColorChanged(Vec3f)),        southernMinorStandstillLine4, SLOT(setColor(Vec3f)));
+	connect(this, SIGNAL(minorStandstillColorChanged(Vec3f)),        southernMinorStandstillLine5, SLOT(setColor(Vec3f)));
+	connect(this, SIGNAL(zenithPassageColorChanged(Vec3f)),          zenithPassageLine           , SLOT(setColor(Vec3f)));
+	connect(this, SIGNAL(nadirPassageColorChanged(Vec3f)),           nadirPassageLine            , SLOT(setColor(Vec3f)));
+	connect(this, SIGNAL(selectedObjectColorChanged(Vec3f)),         selectedObjectLine          , SLOT(setColor(Vec3f)));
+	connect(this, SIGNAL(selectedObjectAzimuthColorChanged(Vec3f)),  selectedObjectAzimuthLine   , SLOT(setColor(Vec3f)));
+	connect(this, SIGNAL(selectedObjectHourAngleColorChanged(Vec3f)),selectedObjectHourAngleLine , SLOT(setColor(Vec3f)));
+	connect(this, SIGNAL(currentSunColorChanged(Vec3f)),             currentSunLine              , SLOT(setColor(Vec3f)));
+	connect(this, SIGNAL(currentMoonColorChanged(Vec3f)),            currentMoonLine             , SLOT(setColor(Vec3f)));
+	connect(this, SIGNAL(currentPlanetColorChanged(Vec3f)),          currentPlanetLine           , SLOT(setColor(Vec3f)));
+	connect(this, SIGNAL(geographicLocation1ColorChanged(Vec3f)),    geographicLocation1Line     , SLOT(setColor(Vec3f)));
+	connect(this, SIGNAL(geographicLocation2ColorChanged(Vec3f)),    geographicLocation2Line     , SLOT(setColor(Vec3f)));
+	connect(this, SIGNAL(customAzimuth1ColorChanged(Vec3f)),         customAzimuth1Line          , SLOT(setColor(Vec3f)));
+	connect(this, SIGNAL(customAzimuth2ColorChanged(Vec3f)),         customAzimuth2Line          , SLOT(setColor(Vec3f)));
+	connect(this, SIGNAL(customDeclination1ColorChanged(Vec3f)),     customDeclination1Line      , SLOT(setColor(Vec3f)));
+	connect(this, SIGNAL(customDeclination2ColorChanged(Vec3f)),     customDeclination2Line      , SLOT(setColor(Vec3f)));
+
+	StelApp& app=StelApp::getInstance();
+	connect(&app, SIGNAL(screenFontSizeChanged(int)), equinoxLine                 , SLOT(setFontSizeFromApp(const int)));
+	connect(&app, SIGNAL(screenFontSizeChanged(int)), northernSolsticeLine        , SLOT(setFontSizeFromApp(const int)));
+	connect(&app, SIGNAL(screenFontSizeChanged(int)), southernSolsticeLine        , SLOT(setFontSizeFromApp(const int)));
+	connect(&app, SIGNAL(screenFontSizeChanged(int)), northernCrossquarterLine    , SLOT(setFontSizeFromApp(const int)));
+	connect(&app, SIGNAL(screenFontSizeChanged(int)), southernCrossquarterLine    , SLOT(setFontSizeFromApp(const int)));
+	connect(&app, SIGNAL(screenFontSizeChanged(int)), northernMajorStandstillLine0, SLOT(setFontSizeFromApp(const int)));
+	connect(&app, SIGNAL(screenFontSizeChanged(int)), northernMajorStandstillLine1, SLOT(setFontSizeFromApp(const int)));
+	connect(&app, SIGNAL(screenFontSizeChanged(int)), southernMajorStandstillLine6, SLOT(setFontSizeFromApp(const int)));
+	connect(&app, SIGNAL(screenFontSizeChanged(int)), southernMajorStandstillLine7, SLOT(setFontSizeFromApp(const int)));
+	connect(&app, SIGNAL(screenFontSizeChanged(int)), northernMinorStandstillLine2, SLOT(setFontSizeFromApp(const int)));
+	connect(&app, SIGNAL(screenFontSizeChanged(int)), northernMinorStandstillLine3, SLOT(setFontSizeFromApp(const int)));
+	connect(&app, SIGNAL(screenFontSizeChanged(int)), southernMinorStandstillLine4, SLOT(setFontSizeFromApp(const int)));
+	connect(&app, SIGNAL(screenFontSizeChanged(int)), southernMinorStandstillLine5, SLOT(setFontSizeFromApp(const int)));
+	connect(&app, SIGNAL(screenFontSizeChanged(int)), zenithPassageLine           , SLOT(setFontSizeFromApp(const int)));
+	connect(&app, SIGNAL(screenFontSizeChanged(int)), nadirPassageLine            , SLOT(setFontSizeFromApp(const int)));
+	connect(&app, SIGNAL(screenFontSizeChanged(int)), selectedObjectLine          , SLOT(setFontSizeFromApp(const int)));
+	connect(&app, SIGNAL(screenFontSizeChanged(int)), selectedObjectAzimuthLine   , SLOT(setFontSizeFromApp(const int)));
+	connect(&app, SIGNAL(screenFontSizeChanged(int)), selectedObjectHourAngleLine , SLOT(setFontSizeFromApp(const int)));
+	connect(&app, SIGNAL(screenFontSizeChanged(int)), currentSunLine              , SLOT(setFontSizeFromApp(const int)));
+	connect(&app, SIGNAL(screenFontSizeChanged(int)), currentMoonLine             , SLOT(setFontSizeFromApp(const int)));
+	connect(&app, SIGNAL(screenFontSizeChanged(int)), currentPlanetLine           , SLOT(setFontSizeFromApp(const int)));
+	connect(&app, SIGNAL(screenFontSizeChanged(int)), geographicLocation1Line     , SLOT(setFontSizeFromApp(const int)));
+	connect(&app, SIGNAL(screenFontSizeChanged(int)), geographicLocation2Line     , SLOT(setFontSizeFromApp(const int)));
+	connect(&app, SIGNAL(screenFontSizeChanged(int)), customAzimuth1Line          , SLOT(setFontSizeFromApp(const int)));
+	connect(&app, SIGNAL(screenFontSizeChanged(int)), customAzimuth2Line          , SLOT(setFontSizeFromApp(const int)));
+	connect(&app, SIGNAL(screenFontSizeChanged(int)), customDeclination1Line      , SLOT(setFontSizeFromApp(const int)));
+	connect(&app, SIGNAL(screenFontSizeChanged(int)), customDeclination2Line      , SLOT(setFontSizeFromApp(const int)));
+
+//	if (!conf->childGroups().contains("ArchaeoLines"))
 //	if (!conf->childGroups().contains("ArchaeoLines"))
 //		restoreDefaultSettings();
 
 	loadSettings();
 
-	StelApp& app = StelApp::getInstance();
-
 	// Create action for enable/disable & hook up signals
 	QString section=N_("ArchaeoLines");
 	addAction("actionShow_ArchaeoLines",         section, N_("ArchaeoLines"), "enabled", "Ctrl+U");
@@ -481,52 +537,25 @@ void ArchaeoLines::restoreDefaultSettings()
 
 void ArchaeoLines::loadSettings()
 {
-	equinoxColor         = StelUtils::strToVec3f(conf->value("ArchaeoLines/color_equinox",          "1.00,1.00,0.50").toString());
-	equinoxLine->setColor(equinoxColor);
-	solsticesColor       = StelUtils::strToVec3f(conf->value("ArchaeoLines/color_solstices",        "1.00,0.15,0.15").toString());
-	northernSolsticeLine->setColor(solsticesColor);
-	southernSolsticeLine->setColor(solsticesColor);
-	crossquartersColor   = StelUtils::strToVec3f(conf->value("ArchaeoLines/color_crossquarters",    "1.00,0.75,0.25").toString());
-	northernCrossquarterLine->setColor(crossquartersColor);
-	southernCrossquarterLine->setColor(crossquartersColor);
-	majorStandstillColor = StelUtils::strToVec3f(conf->value("ArchaeoLines/color_major_standstill", "0.25,1.00,0.25").toString());
-	northernMajorStandstillLine0->setColor(majorStandstillColor);
-	northernMajorStandstillLine1->setColor(majorStandstillColor);
-	southernMajorStandstillLine6->setColor(majorStandstillColor);
-	southernMajorStandstillLine7->setColor(majorStandstillColor);
-	minorStandstillColor = StelUtils::strToVec3f(conf->value("ArchaeoLines/color_minor_standstill", "0.20,0.75,0.20").toString());
-	northernMinorStandstillLine2->setColor(minorStandstillColor);
-	northernMinorStandstillLine3->setColor(minorStandstillColor);
-	southernMinorStandstillLine4->setColor(minorStandstillColor);
-	southernMinorStandstillLine5->setColor(minorStandstillColor);
-	zenithPassageColor   = StelUtils::strToVec3f(conf->value("ArchaeoLines/color_zenith_passage",   "0.75,0.75,0.75").toString());
-	zenithPassageLine->setColor(zenithPassageColor);
-	nadirPassageColor    = StelUtils::strToVec3f(conf->value("ArchaeoLines/color_nadir_passage",    "0.25,0.25,0.25").toString());
-	nadirPassageLine->setColor(nadirPassageColor);
-	selectedObjectColor    = StelUtils::strToVec3f(conf->value("ArchaeoLines/color_selected_object",    "1.00,1.00,1.00").toString());
-	selectedObjectLine->setColor(selectedObjectColor);
-	selectedObjectAzimuthColor = StelUtils::strToVec3f(conf->value("ArchaeoLines/color_selected_object_azimuth", "1.00,1.00,1.00").toString());
-	selectedObjectAzimuthLine->setColor(selectedObjectAzimuthColor);
-	selectedObjectHourAngleColor = StelUtils::strToVec3f(conf->value("ArchaeoLines/color_selected_object_hour_angle", "1.00,1.00,1.00").toString());
-	selectedObjectHourAngleLine->setColor(selectedObjectHourAngleColor);
-	currentSunColor    = StelUtils::strToVec3f(conf->value("ArchaeoLines/color_current_sun",    "1.00,1.00,0.75").toString());
-	currentSunLine->setColor(currentSunColor);
-	currentMoonColor    = StelUtils::strToVec3f(conf->value("ArchaeoLines/color_current_moon",    "0.50,1.00,0.50").toString());
-	currentMoonLine->setColor(currentMoonColor);
-	currentPlanetColor    = StelUtils::strToVec3f(conf->value("ArchaeoLines/color_current_planet",    "0.25,0.80,1.00").toString());
-	currentPlanetLine->setColor(currentPlanetColor);
-	geographicLocation1Color   = StelUtils::strToVec3f(conf->value("ArchaeoLines/color_geographic_location_1",    "0.25,1.00,0.25").toString());
-	geographicLocation1Line->setColor(geographicLocation1Color);
-	geographicLocation2Color   = StelUtils::strToVec3f(conf->value("ArchaeoLines/color_geographic_location_2",    "0.25,0.25,1.00").toString());
-	geographicLocation2Line->setColor(geographicLocation2Color);
-	customAzimuth1Color   = StelUtils::strToVec3f(conf->value("ArchaeoLines/color_custom_azimuth_1",    "0.25,1.00,0.25").toString());
-	customAzimuth1Line->setColor(customAzimuth1Color);
-	customAzimuth2Color   = StelUtils::strToVec3f(conf->value("ArchaeoLines/color_custom_azimuth_2",    "0.25,0.50,0.75").toString());
-	customAzimuth2Line->setColor(customAzimuth2Color);
-	customDeclination1Color   = StelUtils::strToVec3f(conf->value("ArchaeoLines/color_custom_declination_1",    "0.45,1.00,0.15").toString());
-	customDeclination1Line->setColor(customDeclination1Color);
-	customDeclination2Color   = StelUtils::strToVec3f(conf->value("ArchaeoLines/color_custom_declination_2",    "0.45,0.50,0.65").toString());
-	customDeclination2Line->setColor(customDeclination2Color);
+	setEquinoxColor(                StelUtils::strToVec3f(conf->value("ArchaeoLines/color_equinox",                    "1.00,1.00,0.50").toString()));
+	setSolsticesColor(              StelUtils::strToVec3f(conf->value("ArchaeoLines/color_solstices",                  "1.00,0.15,0.15").toString()));
+	setCrossquartersColor(          StelUtils::strToVec3f(conf->value("ArchaeoLines/color_crossquarters",              "1.00,0.75,0.25").toString()));
+	setMajorStandstillColor(        StelUtils::strToVec3f(conf->value("ArchaeoLines/color_major_standstill",           "0.25,1.00,0.25").toString()));
+	setMinorStandstillColor(        StelUtils::strToVec3f(conf->value("ArchaeoLines/color_minor_standstill",           "0.20,0.75,0.20").toString()));
+	setZenithPassageColor(          StelUtils::strToVec3f(conf->value("ArchaeoLines/color_zenith_passage",             "0.75,0.75,0.75").toString()));
+	setNadirPassageColor(           StelUtils::strToVec3f(conf->value("ArchaeoLines/color_nadir_passage",              "0.25,0.25,0.25").toString()));
+	setSelectedObjectColor(         StelUtils::strToVec3f(conf->value("ArchaeoLines/color_selected_object",            "1.00,1.00,1.00").toString()));
+	setSelectedObjectAzimuthColor(  StelUtils::strToVec3f(conf->value("ArchaeoLines/color_selected_object_azimuth",    "1.00,1.00,1.00").toString()));
+	setSelectedObjectHourAngleColor(StelUtils::strToVec3f(conf->value("ArchaeoLines/color_selected_object_hour_angle", "1.00,1.00,1.00").toString()));
+	setCurrentSunColor(             StelUtils::strToVec3f(conf->value("ArchaeoLines/color_current_sun",                "1.00,1.00,0.75").toString()));
+	setCurrentMoonColor(            StelUtils::strToVec3f(conf->value("ArchaeoLines/color_current_moon",               "0.50,1.00,0.50").toString()));
+	setCurrentPlanetColor(          StelUtils::strToVec3f(conf->value("ArchaeoLines/color_current_planet",             "0.25,0.80,1.00").toString()));
+	setGeographicLocation1Color(    StelUtils::strToVec3f(conf->value("ArchaeoLines/color_geographic_location_1",      "0.25,1.00,0.25").toString()));
+	setGeographicLocation2Color(    StelUtils::strToVec3f(conf->value("ArchaeoLines/color_geographic_location_2",      "0.25,0.25,1.00").toString()));
+	setCustomAzimuth1Color(         StelUtils::strToVec3f(conf->value("ArchaeoLines/color_custom_azimuth_1",           "0.25,1.00,0.25").toString()));
+	setCustomAzimuth2Color(         StelUtils::strToVec3f(conf->value("ArchaeoLines/color_custom_azimuth_2",           "0.25,0.50,0.75").toString()));
+	setCustomDeclination1Color(     StelUtils::strToVec3f(conf->value("ArchaeoLines/color_custom_declination_1",       "0.45,1.00,0.15").toString()));
+	setCustomDeclination2Color(     StelUtils::strToVec3f(conf->value("ArchaeoLines/color_custom_declination_2",       "0.45,0.50,0.65").toString()));
 
 	setGeographicLocation1Longitude(conf->value("ArchaeoLines/geographic_location_1_longitude",  39.826175).toDouble());
 	setGeographicLocation1Latitude( conf->value("ArchaeoLines/geographic_location_1_latitude",   21.422476).toDouble());
@@ -923,7 +952,7 @@ void ArchaeoLines::setCustomDeclination2Label(QString label)
 	emit customDeclination2LabelChanged(label);
 }
 
-
+/*
 // called by the dialog UI, converts QColor (0..255) to Stellarium's Vec3f float color.
 void ArchaeoLines::setLineColor(ArchaeoLine::Line whichLine, QColor color)
 {
@@ -1040,11 +1069,12 @@ void ArchaeoLines::setLineColor(ArchaeoLine::Line whichLine, QColor color)
 			Q_ASSERT(0);
 	}
 }
+*/
 
 // called by the dialog UI, converts Stellarium's Vec3f float color to QColor (0..255).
+/*
 QColor ArchaeoLines::getLineColor(ArchaeoLine::Line whichLine) const
 {
-	QColor color(0,0,0);
 	const Vec3f* vColor;
 	switch (whichLine){
 		case ArchaeoLine::Equinox:
@@ -1113,9 +1143,163 @@ QColor ArchaeoLines::getLineColor(ArchaeoLine::Line whichLine) const
 			vColor=&selectedObjectColor; // this is only to silence compiler warning about uninitialized variable vColor.
 			Q_ASSERT(0);
 	}
-	color.setRgbF(vColor->v[0], vColor->v[1], vColor->v[2]);
-	return color;
+	return QColor.fromRgbF(vColor->v[0], vColor->v[1], vColor->v[2]);
 }
+*/
+void ArchaeoLines::setEquinoxColor(Vec3f color)
+{
+	if (color!=getEquinoxColor())
+	{
+		equinoxColor=color;
+		emit equinoxColorChanged(color);
+	}
+}
+void ArchaeoLines::setSolsticesColor(Vec3f color)
+{
+	if (color!=getSolsticesColor())
+	{
+		solsticesColor=color;
+		emit solsticesColorChanged(color);
+	}
+}
+void ArchaeoLines::setCrossquartersColor(Vec3f color)
+{
+	if (color!=getCrossquartersColor())
+	{
+		crossquartersColor=color;
+		emit crossquartersColorChanged(color);
+	}
+}
+void ArchaeoLines::setMajorStandstillColor(Vec3f color)
+{
+	if (color!=getMajorStandstillColor())
+	{
+		majorStandstillColor=color;
+		emit majorStandstillColorChanged(color);
+	}
+}
+void ArchaeoLines::setMinorStandstillColor(Vec3f color)
+{
+	if (color!=getMinorStandstillColor())
+	{
+		minorStandstillColor=color;
+		emit minorStandstillColorChanged(color);
+	}
+}
+void ArchaeoLines::setZenithPassageColor(Vec3f color)
+{
+	if (color!=getZenithPassageColor())
+	{
+		zenithPassageColor=color;
+		emit zenithPassageColorChanged(color);
+	}
+}
+void ArchaeoLines::setNadirPassageColor(Vec3f color)
+{
+	if (color!=getNadirPassageColor())
+	{
+		nadirPassageColor=color;
+		emit nadirPassageColorChanged(color);
+	}
+}
+void ArchaeoLines::setSelectedObjectColor(Vec3f color)
+{
+	if (color!=getSelectedObjectColor())
+	{
+		selectedObjectColor=color;
+		emit selectedObjectColorChanged(color);
+	}
+}
+void ArchaeoLines::setSelectedObjectAzimuthColor(Vec3f color)
+{
+	if (color!=getSelectedObjectAzimuthColor())
+	{
+		selectedObjectAzimuthColor=color;
+		emit selectedObjectAzimuthColorChanged(color);
+	}
+}
+void ArchaeoLines::setSelectedObjectHourAngleColor(Vec3f color)
+{
+	if (color!=getSelectedObjectHourAngleColor())
+	{
+		selectedObjectHourAngleColor=color;
+		emit selectedObjectHourAngleColorChanged(color);
+	}
+}
+void ArchaeoLines::setCurrentSunColor(Vec3f color)
+{
+	if (color!=getCurrentSunColor())
+	{
+		currentSunColor=color;
+		emit currentSunColorChanged(color);
+	}
+}
+void ArchaeoLines::setCurrentMoonColor(Vec3f color)
+{
+	if (color!=getCurrentMoonColor())
+	{
+		currentMoonColor=color;
+		emit currentMoonColorChanged(color);
+	}
+}
+void ArchaeoLines::setCurrentPlanetColor(Vec3f color)
+{
+	if (color!=getCurrentPlanetColor())
+	{
+		currentPlanetColor=color;
+		emit currentPlanetColorChanged(color);
+	}
+}
+void ArchaeoLines::setGeographicLocation1Color(Vec3f color)
+{
+	if (color!=getGeographicLocation1Color())
+	{
+		geographicLocation1Color=color;
+		emit geographicLocation1ColorChanged(color);
+	}
+}
+void ArchaeoLines::setGeographicLocation2Color(Vec3f color)
+{
+	if (color!=getGeographicLocation2Color())
+	{
+		geographicLocation2Color=color;
+		emit geographicLocation2ColorChanged(color);
+	}
+}
+void ArchaeoLines::setCustomAzimuth1Color(Vec3f color)
+{
+	if (color!=getCustomAzimuth1Color())
+	{
+		customAzimuth1Color=color;
+		emit customAzimuth1ColorChanged(color);
+	}
+}
+void ArchaeoLines::setCustomAzimuth2Color(Vec3f color)
+{
+	if (color!=getCustomAzimuth2Color())
+	{
+		customAzimuth2Color=color;
+		emit customAzimuth2ColorChanged(color);
+	}
+}
+void ArchaeoLines::setCustomDeclination1Color(Vec3f color)
+{
+	if (color!=getCustomDeclination1Color())
+	{
+		customDeclination1Color=color;
+		emit customDeclination1ColorChanged(color);
+	}
+}
+void ArchaeoLines::setCustomDeclination2Color(Vec3f color)
+{
+	if (color!=getCustomDeclination2Color())
+	{
+		customDeclination2Color=color;
+		emit customDeclination2ColorChanged(color);
+	}
+}
+
+
 
 double ArchaeoLines::getLineAngle(ArchaeoLine::Line whichLine) const
 {
@@ -1312,6 +1496,7 @@ void alViewportEdgeIntersectCallback(const Vec3d& screenPos, const Vec3d& direct
 	d->sPainter->setBlending(true);
 }
 
+///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
 ArchaeoLine::ArchaeoLine(ArchaeoLine::Line lineType, double definingAngle) :
 	lineType(lineType), definingAngle(definingAngle), color(0.f, 0.f, 1.f), frameType(StelCore::FrameEquinoxEqu), flagLabel(true)
@@ -1319,7 +1504,7 @@ ArchaeoLine::ArchaeoLine(ArchaeoLine::Line lineType, double definingAngle) :
 	if (lineType>=SelectedObjectAzimuth)
 		frameType=StelCore::FrameAltAz;
 	// Font size is 14
-	font.setPixelSize(StelApp::getInstance().getBaseFontSize()+1);
+	setFontSizeFromApp(StelApp::getInstance().getScreenFontSize());
 	updateLabel();
 	fader.setDuration(1000);
 	// Initialize the message strings and make sure they are translated when the language changes.
