@@ -52,7 +52,7 @@ StelPluginInfo EquationOfTimeStelPluginInterface::getPluginInfo() const
 	info.id = "EquationOfTime";
 	info.displayedName = N_("Equation of Time");
 	info.authors = "Alexander Wolf";
-	info.contact = "http://stellarium.org";
+	info.contact = STELLARIUM_URL;
 	info.description = N_("This plugin shows the solution of the equation of time.");
 	info.version = EQUATIONOFTIME_PLUGIN_VERSION;
 	info.license = EQUATIONOFTIME_PLUGIN_LICENSE;
