@@ -16,8 +16,8 @@
  * Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA  02110-1335, USA.
  */
 
-#ifndef _EXOPLANET_HPP_
-#define _EXOPLANET_HPP_ 1
+#ifndef EXOPLANET_HPP
+#define EXOPLANET_HPP
 
 #include <QVariant>
 #include <QString>
@@ -231,4 +231,4 @@ private:
 	LinearFader labelsFader;
 };
 
-#endif // _EXOPLANET_HPP_
+#endif // EXOPLANET_HPP
