@@ -84,7 +84,8 @@ Novae::Novae()
 	: NovaCnt(0)
 	, texPointer(Q_NULLPTR)
 	, updateState(CompleteNoUpdates)
-	, downloadMgr(Q_NULLPTR)
+	, networkManager(Q_NULLPTR)
+	, downloadReply(Q_NULLPTR)
 	, progressBar(Q_NULLPTR)
 	, updateTimer(Q_NULLPTR)
 	, updatesEnabled(false)
@@ -93,7 +94,8 @@ Novae::Novae()
 	setObjectName("Novae");
 	configDialog = new NovaeDialog();
 	conf = StelApp::getInstance().getSettings();
-	font.setPixelSize(StelApp::getInstance().getBaseFontSize());
+	setFontSize(StelApp::getInstance().getScreenFontSize());
+	connect(&StelApp::getInstance(), SIGNAL(screenFontSizeChanged(int)), this, SLOT(setFontSize(int)));
 }
 
 /*
@@ -166,8 +168,7 @@ void Novae::init()
 	readJsonFile();
 
 	// Set up download manager and the update schedule
-	downloadMgr = new QNetworkAccessManager(this);
-	connect(downloadMgr, SIGNAL(finished(QNetworkReply*)), this, SLOT(updateDownloadComplete(QNetworkReply*)));
+	networkManager = StelApp::getInstance().getNetworkAccessManager();
 	updateState = CompleteNoUpdates;
 	updateTimer = new QTimer(this);
 	updateTimer->setSingleShot(false);   // recurring check for update
@@ -175,6 +176,8 @@ void Novae::init()
 	connect(updateTimer, SIGNAL(timeout()), this, SLOT(checkForUpdate()));
 	updateTimer->start();
 
+	connect(this, SIGNAL(jsonUpdateComplete(void)), this, SLOT(reloadCatalog()));
+
 	GETSTELMODULE(StelObjectMgr)->registerStelObjectMgr(this);
 }
 
@@ -419,8 +422,16 @@ QVariantMap Novae::loadNovaeMap(QString path)
 		qWarning() << "[Novae] cannot open" << QDir::toNativeSeparators(path);
 	else
 	{
-		map = StelJsonParser::parse(jsonFile.readAll()).toMap();
-		jsonFile.close();
+		try
+		{
+			map = StelJsonParser::parse(jsonFile.readAll()).toMap();
+			jsonFile.close();
+		}
+		catch (std::runtime_error &e)
+		{
+			qDebug() << "[Novae] File format is wrong! Error: " << e.what();
+			return QVariantMap();
+		}
 	}
 	return map;
 }
@@ -460,13 +471,20 @@ int Novae::getJsonFileVersion(void) const
 	}
 
 	QVariantMap map;
-	map = StelJsonParser::parse(&novaeJsonFile).toMap();
+	try
+	{
+		map = StelJsonParser::parse(&novaeJsonFile).toMap();
+		novaeJsonFile.close();
+	}
+	catch (std::runtime_error &e)
+	{
+		qDebug() << "[Novae] File format is wrong! Error: " << e.what();
+		return jsonVersion;
+	}
 	if (map.contains("version"))
 	{
 		jsonVersion = map.value("version").toInt();
 	}
-
-	novaeJsonFile.close();
 	qDebug() << "[Novae] version of the catalog:" << jsonVersion;
 	return jsonVersion;
 }
@@ -528,7 +546,7 @@ void Novae::restoreDefaultConfigIni(void)
 	conf->remove("");
 
 	conf->setValue("updates_enabled", true);
-	conf->setValue("url", "http://stellarium.org/json/novae.json");
+	conf->setValue("url", "https://stellarium.org/json/novae.json");
 	conf->setValue("update_frequency_days", 100);
 	conf->endGroup();
 }
@@ -537,7 +555,7 @@ void Novae::readSettingsFromConfig(void)
 {
 	conf->beginGroup("Novae");
 
-	updateUrl = conf->value("url", "http://stellarium.org/json/novae.json").toString();
+	updateUrl = conf->value("url", "https://stellarium.org/json/novae.json").toString();
 	updateFrequencyDays = conf->value("update_frequency_days", 100).toInt();
 	lastUpdate = QDateTime::fromString(conf->value("last_update", "2013-08-28T12:00:00").toString(), Qt::ISODate);
 	updatesEnabled = conf->value("updates_enabled", true).toBool();
@@ -564,7 +582,7 @@ int Novae::getSecondsToUpdate(void)
 
 void Novae::checkForUpdate(void)
 {
-	if (updatesEnabled && lastUpdate.addSecs(updateFrequencyDays * 3600 * 24) <= QDateTime::currentDateTime() && downloadMgr->networkAccessible()==QNetworkAccessManager::Accessible)
+	if (updatesEnabled && lastUpdate.addSecs(updateFrequencyDays * 3600 * 24) <= QDateTime::currentDateTime() && networkManager->networkAccessible()==QNetworkAccessManager::Accessible)
 		updateJSON();
 }
 
@@ -575,72 +593,148 @@ void Novae::updateJSON(void)
 		qWarning() << "[Novae] already updating...  will not start again current update is complete.";
 		return;
 	}
-	else
-	{
-		qDebug() << "[Novae] starting update...";
-	}
 
-	lastUpdate = QDateTime::currentDateTime();
-	conf->setValue("Novae/last_update", lastUpdate.toString(Qt::ISODate));
+	qDebug() << "[Novae] Updating novae catalog...";
+	startDownload(updateUrl);
 
-	updateState = Novae::Updating;
-	emit(updateStateChanged(updateState));
-
-	if (progressBar==Q_NULLPTR)
-		progressBar = StelApp::getInstance().addProgressBar();
-
-	progressBar->setValue(0);
-	progressBar->setRange(0, 100);
-	progressBar->setFormat("Update novae");
-	
-
-	QNetworkRequest request;
-	request.setUrl(QUrl(updateUrl));
-	request.setRawHeader("User-Agent", QString("Mozilla/5.0 (Stellarium Bright Novae Plugin %1; http://stellarium.org/)").arg(NOVAE_PLUGIN_VERSION).toUtf8());
-	downloadMgr->get(request);
-
-	updateState = Novae::CompleteUpdates;
-	emit(updateStateChanged(updateState));
-	emit(jsonUpdateComplete());
 }
 
-void Novae::updateDownloadComplete(QNetworkReply* reply)
+void Novae::deleteDownloadProgressBar()
 {
-	// check the download worked, and save the data to file if this is the case.
-	if (reply->error() == QNetworkReply::NoError && reply->bytesAvailable()>0)
-	{
-		// download completed successfully.
-		QString jsonFilePath = StelFileMgr::findFile("modules/Novae", StelFileMgr::Flags(StelFileMgr::Writable|StelFileMgr::Directory)) + "/novae.json";
-		if (jsonFilePath.isEmpty())
-		{
-			qWarning() << "[Novae] cannot write JSON data to file";
-		}
-		else
-		{
-			QFile jsonFile(jsonFilePath);
-			if (jsonFile.exists())
-				jsonFile.remove();
-
-			if(jsonFile.open(QIODevice::WriteOnly | QIODevice::Text))
-			{
-				jsonFile.write(reply->readAll());
-				jsonFile.close();
-			}
-		}
-	}
-	else
-		qWarning() << "[Novae] FAILED to download" << reply->url() << " Error: " << reply->errorString();
+	disconnect(this, SLOT(updateDownloadProgress(qint64,qint64)));
 
 	if (progressBar)
 	{
-		progressBar->setValue(100);
 		StelApp::getInstance().removeProgressBar(progressBar);
 		progressBar = Q_NULLPTR;
 	}
+}
+
+void Novae::startDownload(QString urlString)
+{
+	QUrl url(urlString);
+	if (!url.isValid() || url.isRelative() || !url.scheme().startsWith("http", Qt::CaseInsensitive))
+	{
+		qWarning() << "[Novae] Invalid URL:" << urlString;
+		return;
+	}
+
+	if (progressBar == Q_NULLPTR)
+		progressBar = StelApp::getInstance().addProgressBar();
+	progressBar->setValue(0);
+	progressBar->setRange(0, 0);
+
+	connect(networkManager, SIGNAL(finished(QNetworkReply*)), this, SLOT(downloadComplete(QNetworkReply*)));
+	QNetworkRequest request;
+	request.setUrl(QUrl(updateUrl));
+	request.setRawHeader("User-Agent", StelUtils::getUserAgentString().toUtf8());
+	#if QT_VERSION >= 0x050600
+	request.setAttribute(QNetworkRequest::FollowRedirectsAttribute, true);
+	#endif
+	downloadReply = networkManager->get(request);
+	connect(downloadReply, SIGNAL(downloadProgress(qint64,qint64)), this, SLOT(updateDownloadProgress(qint64,qint64)));
+
+	updateState = Novae::Updating;
+	emit(updateStateChanged(updateState));
+}
+
+void Novae::updateDownloadProgress(qint64 bytesReceived, qint64 bytesTotal)
+{
+	if (progressBar == Q_NULLPTR)
+		return;
+
+	int currentValue = 0;
+	int endValue = 0;
+
+	if (bytesTotal > -1 && bytesReceived <= bytesTotal)
+	{
+		//Round to the greatest possible derived unit
+		while (bytesTotal > 1024)
+		{
+			bytesReceived = std::floor(bytesReceived / 1024.);
+			bytesTotal    = std::floor(bytesTotal / 1024.);
+		}
+		currentValue = bytesReceived;
+		endValue = bytesTotal;
+	}
+
+	progressBar->setValue(currentValue);
+	progressBar->setRange(0, endValue);
+}
+
+void Novae::downloadComplete(QNetworkReply *reply)
+{
+	if (reply == Q_NULLPTR)
+		return;
+
+	disconnect(networkManager, SIGNAL(finished(QNetworkReply*)), this, SLOT(downloadComplete(QNetworkReply*)));
+
+	#if QT_VERSION < 0x050600
+	int statusCode = reply->attribute(QNetworkRequest::HttpStatusCodeAttribute).toInt();
+	if (statusCode == 301 || statusCode == 302 || statusCode == 307)
+	{
+		QUrl rawUrl = reply->attribute(QNetworkRequest::RedirectionTargetAttribute).toUrl();
+		QUrl redirectUrl(rawUrl.toString(QUrl::RemoveQuery));
+		qDebug() << "[Novae] The query has been redirected to" << redirectUrl.toString();
+		updateUrl = redirectUrl.toString();
+		conf->setValue("Novae/url", updateUrl);
+		reply->deleteLater();
+		downloadReply = Q_NULLPTR;
+		startDownload(redirectUrl.toString());
+		return;
+	}
+	#endif
+
+	deleteDownloadProgressBar();
+
+	if (reply->error() || reply->bytesAvailable()==0)
+	{
+		qWarning() << "[Novae] Download error: While trying to access"
+			   << reply->url().toString()
+			   << "the following error occured:"
+			   << reply->errorString();
+
+		reply->deleteLater();
+		downloadReply = Q_NULLPTR;
+		return;
+	}
+
+	// download completed successfully.
+	try
+	{
+		QString jsonFilePath = StelFileMgr::findFile("modules/Novae", StelFileMgr::Flags(StelFileMgr::Writable|StelFileMgr::Directory)) + "/novae.json";
+		QFile jsonFile(jsonFilePath);
+		if (jsonFile.exists())
+			jsonFile.remove();
+
+		if (jsonFile.open(QIODevice::WriteOnly | QIODevice::Text))
+		{
+			jsonFile.write(reply->readAll());
+			jsonFile.close();
+		}
+
+		updateState = Novae::CompleteUpdates;
+
+		lastUpdate = QDateTime::currentDateTime();
+		conf->setValue("Novae/last_update", lastUpdate.toString(Qt::ISODate));
+
+	}
+	catch (std::runtime_error &e)
+	{
+		qWarning() << "[Novae] Cannot write JSON data to file:" << e.what();
+		updateState = Novae::DownloadError;
+	}
+
+	emit(updateStateChanged(updateState));
+	emit(jsonUpdateComplete());
+
+	reply->deleteLater();
+	downloadReply = Q_NULLPTR;
 
 	readJsonFile();
 }
 
+
 void Novae::displayMessage(const QString& message, const QString hexColor)
 {
 	messageIDs << GETSTELMODULE(LabelMgr)->labelScreen(message, 30, 30 + (20*messageIDs.count()), true, 16, hexColor, false, 9000);
@@ -673,13 +767,20 @@ float Novae::getLowerLimitBrightness()
 	}
 
 	QVariantMap map;
-	map = StelJsonParser::parse(&novaeJsonFile).toMap();
+	try
+	{
+		map = StelJsonParser::parse(&novaeJsonFile).toMap();
+		novaeJsonFile.close();
+	}
+	catch (std::runtime_error &e)
+	{
+		qDebug() << "[Novae] File format is wrong! Error: " << e.what();
+		return lowerLimit;
+	}
 	if (map.contains("limit"))
 	{
 		lowerLimit = map.value("limit").toFloat();
 	}
-
-	novaeJsonFile.close();
 	return lowerLimit;
 }
 
