@@ -15,8 +15,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA  02110-1335, USA.
  */
-#ifndef OBSERVABILITY_HPP_
-#define OBSERVABILITY_HPP_
+#ifndef OBSERVABILITY_HPP
+#define OBSERVABILITY_HPP
 
 #include "StelModule.hpp"
 #include <QFont>
@@ -423,4 +423,4 @@ public:
        virtual QObjectList getExtensionList() const { return QObjectList(); }
 };
 
-#endif /*OBSERVABILITY_HPP_*/
+#endif /*OBSERVABILITY_HPP*/
