@@ -18,8 +18,8 @@
  * Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA  02110-1335, USA.
  */
 
-#ifndef _OCULARS_HPP_
-#define _OCULARS_HPP_
+#ifndef OCULARS_HPP
+#define OCULARS_HPP
 
 #include "CCD.hpp"
 #include "Lens.hpp"
@@ -100,8 +100,10 @@ class Oculars : public StelModule
 	Q_PROPERTY(bool flagDMSDegrees         READ getFlagDMSDegrees          WRITE setFlagDMSDegrees          NOTIFY flagDMSDegreesChanged)
 	Q_PROPERTY(bool flagAutosetMountForCCD READ getFlagAutosetMountForCCD  WRITE setFlagAutosetMountForCCD  NOTIFY flagAutosetMountForCCDChanged)
 	Q_PROPERTY(bool flagScalingFOVForTelrad	READ getFlagScalingFOVForTelrad  WRITE setFlagScalingFOVForTelrad  NOTIFY flagScalingFOVForTelradChanged)
+	Q_PROPERTY(bool flagShowOcularsButton	READ getFlagShowOcularsButton  WRITE setFlagShowOcularsButton  NOTIFY flagShowOcularsButtonChanged)
 
 	Q_PROPERTY(double arrowButtonScale     READ getArrowButtonScale        WRITE setArrowButtonScale        NOTIFY arrowButtonScaleChanged)
+	Q_PROPERTY(int guiPanelFontSize        READ getGuiPanelFontSize        WRITE setGuiPanelFontSize        NOTIFY guiPanelFontSizeChanged)
 
 	//BM: Temporary, until the GUI is finalized and some other method of getting
 	//info from the main class is implemented.
@@ -182,6 +184,8 @@ public slots:
 	
 	void enableGuiPanel(bool enable = true);
 	bool getFlagGuiPanelEnabled(void) const {return flagGuiPanelEnabled;}
+	void setGuiPanelFontSize(int size);
+	int getGuiPanelFontSize()const {return guiPanelFontSize;}
 
 	void setFlagDMSDegrees(const bool b);
 	bool getFlagDMSDegrees(void) const;
@@ -219,6 +223,13 @@ public slots:
 	void setFlagScaleImageCircle(bool state);
 	bool getFlagScaleImageCircle(void) const { return flagScaleImageCircle;}
 
+	//! Define whether the button toggling eyepieces should be visible
+	void setFlagShowOcularsButton(bool b);
+	bool getFlagShowOcularsButton(void) { return flagShowOcularsButton; }
+
+	void setFontSize(int s){font.setPixelSize(s);}
+	//! Connect this to StelApp font size.
+	void setFontSizeFromApp(int s){font.setPixelSize(s+1);}
 signals:
 	void enableOcularChanged(bool value);
 	void enableCrosshairsChanged(bool value);
@@ -231,6 +242,7 @@ signals:
 	void selectedCCDRotationAngleChanged(double value);
 
 	void flagGuiPanelEnabledChanged(bool value);
+	void guiPanelFontSizeChanged(int value);
 	void flagHideGridsLinesChanged(bool value);
 	void flagAutosetMountForCCDChanged(bool value);
 	void flagScalingFOVForTelradChanged(bool value);
@@ -243,6 +255,7 @@ signals:
 	void flagLimitMagnitudeChanged(bool value);
 	void flagDMSDegreesChanged(bool value);
 	void flagScaleImageCircleChanged(bool value);
+	void flagShowOcularsButtonChanged(bool value);
 
 private slots:
 	//! Signifies a change in ocular or telescope.  Sets new zoom level.
@@ -342,6 +355,7 @@ private:
 	float absoluteStarScaleCCD;     //!< Value to store the absolute star scale when switching off CCD view
 	bool flagMoonScaleMain;	        //!< Flag to track of usage zooming of the Moon
 	bool flagMinorBodiesScaleMain;  //!< Flag to track of usage zooming of minor bodies
+	float milkyWaySaturation;
 
 	double maxEyepieceAngle;        //!< The maximum aFOV of any eyepiece.
 	bool flagRequireSelection;      //!< Read from the ini file, whether an object is required to be selected to zoom in.
@@ -372,6 +386,7 @@ private:
 	QPixmap * pxmapOnIcon;
 	QPixmap * pxmapOffIcon;
 	StelButton * toolbarButton;
+	bool flagShowOcularsButton;
 
 	OcularDialog *ocularDialog;
 	bool ready; //!< A flag that determines that this module is usable.  If false, we won't open.
@@ -388,6 +403,7 @@ private:
 	StelAction * actionOcularDecrement;
 
 	class OcularsGuiPanel * guiPanel;
+	int guiPanelFontSize;
 
 	//Reticle
 	StelTextureSP reticleTexture;
@@ -419,4 +435,4 @@ public:
 	virtual QObjectList getExtensionList() const { return QObjectList(); }
 };
 
-#endif /*_OCULARS_HPP_*/
+#endif /* OCULARS_HPP */
