@@ -83,7 +83,8 @@ StelPluginInfo PulsarsStelPluginInterface::getPluginInfo() const
 Pulsars::Pulsars()
 	: PsrCount(0)
 	, updateState(CompleteNoUpdates)
-	, downloadMgr(Q_NULLPTR)
+	, networkManager(Q_NULLPTR)
+	, downloadReply(Q_NULLPTR)
 	, updateTimer(Q_NULLPTR)
 	, updatesEnabled(false)
 	, updateFrequencyDays(0)
@@ -99,7 +100,8 @@ Pulsars::Pulsars()
 	setObjectName("Pulsars");
 	configDialog = new PulsarsDialog();
 	conf = StelApp::getInstance().getSettings();
-	font.setPixelSize(StelApp::getInstance().getBaseFontSize());
+	setFontSize(StelApp::getInstance().getScreenFontSize());
+	connect(&StelApp::getInstance(), SIGNAL(screenFontSizeChanged(int)), this, SLOT(setFontSize(int)));
 }
 
 /*
@@ -199,8 +201,7 @@ void Pulsars::init()
 	readJsonFile();
 
 	// Set up download manager and the update schedule
-	downloadMgr = new QNetworkAccessManager(this);
-	connect(downloadMgr, SIGNAL(finished(QNetworkReply*)), this, SLOT(updateDownloadComplete(QNetworkReply*)));
+	networkManager = StelApp::getInstance().getNetworkAccessManager();
 	updateState = CompleteNoUpdates;
 	updateTimer = new QTimer(this);
 	updateTimer->setSingleShot(false);   // recurring check for update
@@ -208,6 +209,8 @@ void Pulsars::init()
 	connect(updateTimer, SIGNAL(timeout()), this, SLOT(checkForUpdate()));
 	updateTimer->start();
 
+	connect(this, SIGNAL(jsonUpdateComplete(void)), this, SLOT(reloadCatalog()));
+
 	GETSTELMODULE(StelObjectMgr)->registerStelObjectMgr(this);
 }
 
@@ -472,8 +475,16 @@ QVariantMap Pulsars::loadPSRMap(QString path)
 		qWarning() << "[Pulsars] Cannot open" << QDir::toNativeSeparators(path);
 	else
 	{
-		map = StelJsonParser::parse(jsonFile.readAll()).toMap();
-		jsonFile.close();
+		try
+		{
+			map = StelJsonParser::parse(jsonFile.readAll()).toMap();
+			jsonFile.close();
+		}
+		catch (std::runtime_error &e)
+		{
+			qDebug() << "[Pulsars] File format is wrong! Error: " << e.what();
+			return QVariantMap();
+		}
 	}
 	return map;
 }
@@ -511,13 +522,20 @@ int Pulsars::getJsonFileFormatVersion(void)
 	}
 
 	QVariantMap map;
-	map = StelJsonParser::parse(&jsonPSRCatalogFile).toMap();
+	try
+	{
+		map = StelJsonParser::parse(&jsonPSRCatalogFile).toMap();
+		jsonPSRCatalogFile.close();
+	}
+	catch (std::runtime_error &e)
+	{
+		qDebug() << "[Pulsars] File format is wrong! Error: " << e.what();
+		return jsonVersion;
+	}
 	if (map.contains("version"))
 	{
 		jsonVersion = map.value("version").toInt();
 	}
-
-	jsonPSRCatalogFile.close();
 	qDebug() << "[Pulsars] Version of the format of the catalog:" << jsonVersion;
 	return jsonVersion;
 }
@@ -534,7 +552,7 @@ bool Pulsars::checkJsonFileFormat()
 	QVariantMap map;
 	try
 	{
-		map = StelJsonParser::parse(&jsonPSRCatalogFile).toMap();
+		map = StelJsonParser::parse(&jsonPSRCatalogFile).toMap();		
 		jsonPSRCatalogFile.close();
 	}
 	catch (std::runtime_error& e)
@@ -581,7 +599,7 @@ void Pulsars::restoreDefaultConfigIni(void)
 	conf->setValue("distribution_enabled", false);
 	conf->setValue("enable_at_startup", false);
 	conf->setValue("updates_enabled", true);	
-	conf->setValue("url", "http://stellarium.org/json/pulsars.json");
+	conf->setValue("url", "https://stellarium.org/json/pulsars.json");
 	conf->setValue("update_frequency_days", 100);
 	conf->setValue("flag_show_pulsars_button", true);
 	conf->setValue("marker_color", "0.4,0.5,1.0");
@@ -596,7 +614,7 @@ void Pulsars::readSettingsFromConfig(void)
 {
 	conf->beginGroup("Pulsars");
 
-	updateUrl = conf->value("url", "http://stellarium.org/json/pulsars.json").toString();
+	updateUrl = conf->value("url", "https://stellarium.org/json/pulsars.json").toString();
 	updateFrequencyDays = conf->value("update_frequency_days", 100).toInt();
 	lastUpdate = QDateTime::fromString(conf->value("last_update", "2012-05-24T12:00:00").toString(), Qt::ISODate);
 	updatesEnabled = conf->value("updates_enabled", true).toBool();
@@ -604,8 +622,8 @@ void Pulsars::readSettingsFromConfig(void)
 	setGlitchFlag(conf->value("use_separate_colors", false).toBool());
 	setFilteredMode(conf->value("filter_enabled", false).toBool());
 	setFilterValue(conf->value("filter_value", 150.f).toFloat());
-	setMarkerColor(StelUtils::strToVec3f(conf->value("marker_color", "0.4,0.5,1.0").toString()), true);
-	setMarkerColor(StelUtils::strToVec3f(conf->value("glitch_color", "0.2,0.3,1.0").toString()), false);
+	setMarkerColor(StelUtils::strToVec3f(conf->value("marker_color", "0.4,0.5,1.0").toString()));
+	setGlitchColor(StelUtils::strToVec3f(conf->value("glitch_color", "0.2,0.3,1.0").toString()));
 	enableAtStartup = conf->value("enable_at_startup", false).toBool();
 	flagShowPulsarsButton = conf->value("flag_show_pulsars_button", true).toBool();
 
@@ -625,8 +643,8 @@ void Pulsars::saveSettingsToConfig(void)
 	conf->setValue("filter_value", QString::number(getFilterValue(), 'f', 2));
 	conf->setValue("enable_at_startup", enableAtStartup);
 	conf->setValue("flag_show_pulsars_button", flagShowPulsarsButton);
-	conf->setValue("marker_color", StelUtils::vec3fToStr(getMarkerColor(true)));
-	conf->setValue("glitch_color", StelUtils::vec3fToStr(getMarkerColor(false)));
+	conf->setValue("marker_color", StelUtils::vec3fToStr(getMarkerColor()));
+	conf->setValue("glitch_color", StelUtils::vec3fToStr(getGlitchColor()));
 
 	conf->endGroup();
 }
@@ -639,7 +657,7 @@ int Pulsars::getSecondsToUpdate(void)
 
 void Pulsars::checkForUpdate(void)
 {
-	if (updatesEnabled && lastUpdate.addSecs(updateFrequencyDays * 3600 * 24) <= QDateTime::currentDateTime() && downloadMgr->networkAccessible()==QNetworkAccessManager::Accessible)
+	if (updatesEnabled && lastUpdate.addSecs(updateFrequencyDays * 3600 * 24) <= QDateTime::currentDateTime() && networkManager->networkAccessible()==QNetworkAccessManager::Accessible)
 		updateJSON();
 }
 
@@ -650,67 +668,146 @@ void Pulsars::updateJSON(void)
 		qWarning() << "[Pulsars] Already updating...  will not start again current update is complete.";
 		return;
 	}
-	else
-	{
-		qDebug() << "[Pulsars] Starting update...";
-	}
 
-	lastUpdate = QDateTime::currentDateTime();
-	conf->setValue("Pulsars/last_update", lastUpdate.toString(Qt::ISODate));
-
-	updateState = Pulsars::Updating;
-	emit(updateStateChanged(updateState));	
-
-	if (progressBar==Q_NULLPTR)
-		progressBar = StelApp::getInstance().addProgressBar();
-
-	progressBar->setValue(0);
-	progressBar->setRange(0, 100);
-	progressBar->setFormat("Update pulsars");
-
-	QNetworkRequest request;
-	request.setUrl(QUrl(updateUrl));
-	request.setRawHeader("User-Agent", QString("Mozilla/5.0 (Stellarium Pulsars Plugin %1; http://stellarium.org/)").arg(PULSARS_PLUGIN_VERSION).toUtf8());
-	downloadMgr->get(request);
-
-	updateState = Pulsars::CompleteUpdates;
-	emit(updateStateChanged(updateState));
-	emit(jsonUpdateComplete());
+	qDebug() << "[Pulsars] Updating pulsars catalog...";
+	startDownload(updateUrl);
 }
 
-void Pulsars::updateDownloadComplete(QNetworkReply* reply)
+void Pulsars::deleteDownloadProgressBar()
 {
-	// check the download worked, and save the data to file if this is the case.
-	if (reply->error() == QNetworkReply::NoError && reply->bytesAvailable()>0)
+	disconnect(this, SLOT(updateDownloadProgress(qint64,qint64)));
+
+	if (progressBar)
 	{
-		// download completed successfully.
-		QString jsonFilePath = StelFileMgr::findFile("modules/Pulsars", StelFileMgr::Flags(StelFileMgr::Writable|StelFileMgr::Directory)) + "/pulsars.json";
-		if (jsonFilePath.isEmpty())
+		StelApp::getInstance().removeProgressBar(progressBar);
+		progressBar = Q_NULLPTR;
+	}
+}
+
+void Pulsars::startDownload(QString urlString)
+{
+	QUrl url(urlString);
+	if (!url.isValid() || url.isRelative() || !url.scheme().startsWith("http", Qt::CaseInsensitive))
+	{
+		qWarning() << "[Pulsars] Invalid URL:" << urlString;
+		return;
+	}
+
+	if (progressBar == Q_NULLPTR)
+		progressBar = StelApp::getInstance().addProgressBar();
+	progressBar->setValue(0);
+	progressBar->setRange(0, 0);
+
+	connect(networkManager, SIGNAL(finished(QNetworkReply*)), this, SLOT(downloadComplete(QNetworkReply*)));
+	QNetworkRequest request;
+	request.setUrl(QUrl(updateUrl));
+	request.setRawHeader("User-Agent", StelUtils::getUserAgentString().toUtf8());
+	#if QT_VERSION >= 0x050600
+	request.setAttribute(QNetworkRequest::FollowRedirectsAttribute, true);
+	#endif
+	downloadReply = networkManager->get(request);
+	connect(downloadReply, SIGNAL(downloadProgress(qint64,qint64)), this, SLOT(updateDownloadProgress(qint64,qint64)));
+
+	updateState = Pulsars::Updating;
+	emit(updateStateChanged(updateState));
+}
+
+void Pulsars::updateDownloadProgress(qint64 bytesReceived, qint64 bytesTotal)
+{
+	if (progressBar == Q_NULLPTR)
+		return;
+
+	int currentValue = 0;
+	int endValue = 0;
+
+	if (bytesTotal > -1 && bytesReceived <= bytesTotal)
+	{
+		//Round to the greatest possible derived unit
+		while (bytesTotal > 1024)
 		{
-			qWarning() << "[Pulsars] Cannot write JSON data to file:" << QDir::toNativeSeparators(jsonCatalogPath);
-			return;
+			bytesReceived = std::floor(bytesReceived / 1024.);
+			bytesTotal    = std::floor(bytesTotal / 1024.);
 		}
+		currentValue = bytesReceived;
+		endValue = bytesTotal;
+	}
+
+	progressBar->setValue(currentValue);
+	progressBar->setRange(0, endValue);
+}
+
+void Pulsars::downloadComplete(QNetworkReply *reply)
+{
+	if (reply == Q_NULLPTR)
+		return;
+
+	disconnect(networkManager, SIGNAL(finished(QNetworkReply*)), this, SLOT(downloadComplete(QNetworkReply*)));
+
+	#if QT_VERSION < 0x050600
+	int statusCode = reply->attribute(QNetworkRequest::HttpStatusCodeAttribute).toInt();
+	if (statusCode == 301 || statusCode == 302 || statusCode == 307)
+	{
+		QUrl rawUrl = reply->attribute(QNetworkRequest::RedirectionTargetAttribute).toUrl();
+		QUrl redirectUrl(rawUrl.toString(QUrl::RemoveQuery));
+		qDebug() << "[Pulsars] The query has been redirected to" << redirectUrl.toString();
+		updateUrl = redirectUrl.toString();
+		conf->setValue("Pulsars/url", updateUrl);
+		reply->deleteLater();
+		downloadReply = Q_NULLPTR;
+		startDownload(redirectUrl.toString());
+		return;
+	}
+	#endif
+
+	deleteDownloadProgressBar();
+
+	if (reply->error() || reply->bytesAvailable()==0)
+	{
+		qWarning() << "[Pulsars] Download error: While trying to access"
+			   << reply->url().toString()
+			   << "the following error occured:"
+			   << reply->errorString();
+
+		reply->deleteLater();
+		downloadReply = Q_NULLPTR;
+		return;
+	}
+
+	// download completed successfully.
+	try
+	{
+		QString jsonFilePath = StelFileMgr::findFile("modules/Pulsars", StelFileMgr::Flags(StelFileMgr::Writable|StelFileMgr::Directory)) + "/pulsars.json";
 		QFile jsonFile(jsonFilePath);
 		if (jsonFile.exists())
 			jsonFile.remove();
 
-		if(jsonFile.open(QIODevice::WriteOnly | QIODevice::Text))
+		if (jsonFile.open(QIODevice::WriteOnly | QIODevice::Text))
 		{
 			jsonFile.write(reply->readAll());
 			jsonFile.close();
 		}
-	}
-	else
-		qWarning() << "[Pulsars] FAILED to download" << reply->url() << " Error: " << reply->errorString();
 
-	if (progressBar)
-	{
-		progressBar->setValue(100);
-		StelApp::getInstance().removeProgressBar(progressBar);
-		progressBar=Q_NULLPTR;
+		updateState = Pulsars::CompleteUpdates;
+
+		lastUpdate = QDateTime::currentDateTime();
+		conf->setValue("Pulsars/last_update", lastUpdate.toString(Qt::ISODate));
 	}
+	catch (std::runtime_error &e)
+	{
+		qWarning() << "[Pulsars] Cannot write JSON data to file:" << e.what();
+		updateState = Pulsars::DownloadError;
+	}
+
+	emit(updateStateChanged(updateState));
+	emit(jsonUpdateComplete());
+
+	reply->deleteLater();
+	downloadReply = Q_NULLPTR;
+
+	readJsonFile();
 }
 
+
 void Pulsars::displayMessage(const QString& message, const QString hexColor)
 {
 	messageIDs << GETSTELMODULE(LabelMgr)->labelScreen(message, 30, 30 + (20*messageIDs.count()), true, 16, hexColor, false, 9000);
@@ -747,7 +844,7 @@ void Pulsars::setFlagShowPulsarsButton(bool b)
 	flagShowPulsarsButton = b;
 }
 
-bool Pulsars::getDisplayMode()
+bool Pulsars::getDisplayMode() const
 {
 	return Pulsar::distributionMode;
 }
@@ -757,7 +854,7 @@ void Pulsars::setDisplayMode(bool b)
 	Pulsar::distributionMode=b;
 }
 
-bool Pulsars::getGlitchFlag()
+bool Pulsars::getGlitchFlag() const
 {
 	return Pulsar::glitchFlag;
 }
@@ -767,7 +864,7 @@ void Pulsars::setGlitchFlag(bool b)
 	Pulsar::glitchFlag=b;
 }
 
-bool Pulsars::getFilteredMode()
+bool Pulsars::getFilteredMode() const
 {
 	return Pulsar::filteredMode;
 }
@@ -777,7 +874,7 @@ void Pulsars::setFilteredMode(bool b)
 	Pulsar::filteredMode=b;
 }
 
-float Pulsars::getFilterValue()
+float Pulsars::getFilterValue() const
 {
 	return Pulsar::filterValue;
 }
@@ -787,21 +884,26 @@ void Pulsars::setFilterValue(float v)
 	Pulsar::filterValue=v;
 }
 
-Vec3f Pulsars::getMarkerColor(bool mtype)
+Vec3f Pulsars::getMarkerColor() const
 {
-	Vec3f c = Pulsar::glitchColor;
-	if (mtype)
-		c = Pulsar::markerColor;
-
-	return c;
+	return Pulsar::markerColor;
 }
 
-void Pulsars::setMarkerColor(const Vec3f &c, bool mtype)
+void Pulsars::setMarkerColor(const Vec3f &c)
 {
-	if (mtype)
-		Pulsar::markerColor = c;
-	else
-		Pulsar::glitchColor = c;
+	Pulsar::markerColor = c;
+	emit markerColorChanged(c);
+}
+
+Vec3f Pulsars::getGlitchColor() const
+{
+	return Pulsar::glitchColor;
+}
+
+void Pulsars::setGlitchColor(const Vec3f &c)
+{
+	Pulsar::glitchColor = c;
+	emit glitchColorChanged(c);
 }
 
 void Pulsars::reloadCatalog(void)
