@@ -84,7 +84,8 @@ StelPluginInfo QuasarsStelPluginInterface::getPluginInfo() const
 Quasars::Quasars()
 	: QsrCount(0)
 	, updateState(CompleteNoUpdates)
-	, downloadMgr(Q_NULLPTR)
+	, networkManager(Q_NULLPTR)
+	, downloadReply(Q_NULLPTR)
 	, updateTimer(Q_NULLPTR)
 	, messageTimer(Q_NULLPTR)
 	, updatesEnabled(false)
@@ -102,7 +103,8 @@ Quasars::Quasars()
 	setObjectName("Quasars");
 	configDialog = new QuasarsDialog();
 	conf = StelApp::getInstance().getSettings();
-	font.setPixelSize(StelApp::getInstance().getBaseFontSize());
+	setFontSize(StelApp::getInstance().getScreenFontSize());
+	connect(&StelApp::getInstance(), SIGNAL(screenFontSizeChanged(int)), this, SLOT(setFontSize(int)));
 }
 
 /*
@@ -202,8 +204,7 @@ void Quasars::init()
 	readJsonFile();
 
 	// Set up download manager and the update schedule
-	downloadMgr = new QNetworkAccessManager(this);
-	connect(downloadMgr, SIGNAL(finished(QNetworkReply*)), this, SLOT(updateDownloadComplete(QNetworkReply*)));
+	networkManager = StelApp::getInstance().getNetworkAccessManager();
 	updateState = CompleteNoUpdates;
 	updateTimer = new QTimer(this);
 	updateTimer->setSingleShot(false);   // recurring check for update
@@ -211,6 +212,8 @@ void Quasars::init()
 	connect(updateTimer, SIGNAL(timeout()), this, SLOT(checkForUpdate()));
 	updateTimer->start();
 
+	connect(this, SIGNAL(jsonUpdateComplete(void)), this, SLOT(reloadCatalog()));
+
 	GETSTELMODULE(StelObjectMgr)->registerStelObjectMgr(this);
 }
 
@@ -438,8 +441,16 @@ QVariantMap Quasars::loadQSOMap(QString path)
 		qWarning() << "[Quasars] Cannot open" << QDir::toNativeSeparators(path);
 	else
 	{
-		map = StelJsonParser::parse(jsonFile.readAll()).toMap();
-		jsonFile.close();
+		try
+		{
+			map = StelJsonParser::parse(jsonFile.readAll()).toMap();
+			jsonFile.close();
+		}
+		catch (std::runtime_error &e)
+		{
+			qDebug() << "[Quasars] File format is wrong! Error: " << e.what();
+			return QVariantMap();
+		}
 	}
 	return map;
 }
@@ -477,13 +488,20 @@ int Quasars::getJsonFileFormatVersion(void)
 	}
 
 	QVariantMap map;
-	map = StelJsonParser::parse(&catalogJsonFile).toMap();
+	try
+	{
+		map = StelJsonParser::parse(&catalogJsonFile).toMap();
+		catalogJsonFile.close();
+	}
+	catch (std::runtime_error &e)
+	{
+		qDebug() << "[Quasars] File format is wrong! Error: " << e.what();
+		return jsonVersion;
+	}
 	if (map.contains("version"))
 	{
 		jsonVersion = map.value("version").toInt();
 	}
-
-	catalogJsonFile.close();
 	qDebug() << "[Quasars] Version of the format of the catalog:" << jsonVersion;
 	return jsonVersion;
 }
@@ -547,7 +565,7 @@ void Quasars::restoreDefaultConfigIni(void)
 	conf->setValue("distribution_enabled", false);
 	conf->setValue("enable_at_startup", false);
 	conf->setValue("updates_enabled", true);
-	conf->setValue("url", "http://stellarium.org/json/quasars.json");
+	conf->setValue("url", "https://stellarium.org/json/quasars.json");
 	conf->setValue("update_frequency_days", 100);
 	conf->setValue("flag_show_quasars_button", true);
 	conf->setValue("marker_color", "1.0,0.5,0.4");
@@ -558,7 +576,7 @@ void Quasars::readSettingsFromConfig(void)
 {
 	conf->beginGroup("Quasars");
 
-	updateUrl = conf->value("url", "http://stellarium.org/json/quasars.json").toString();
+	updateUrl = conf->value("url", "https://stellarium.org/json/quasars.json").toString();
 	updateFrequencyDays = conf->value("update_frequency_days", 100).toInt();
 	lastUpdate = QDateTime::fromString(conf->value("last_update", "2012-05-24T12:00:00").toString(), Qt::ISODate);
 	updatesEnabled = conf->value("updates_enabled", true).toBool();
@@ -595,7 +613,7 @@ int Quasars::getSecondsToUpdate(void)
 
 void Quasars::checkForUpdate(void)
 {
-	if (updatesEnabled && lastUpdate.addSecs(updateFrequencyDays * 3600 * 24) <= QDateTime::currentDateTime() && downloadMgr->networkAccessible()==QNetworkAccessManager::Accessible)
+	if (updatesEnabled && lastUpdate.addSecs(updateFrequencyDays * 3600 * 24) <= QDateTime::currentDateTime() && networkManager->networkAccessible()==QNetworkAccessManager::Accessible)
 		updateJSON();
 }
 
@@ -606,65 +624,143 @@ void Quasars::updateJSON(void)
 		qWarning() << "[Quasars] Already updating...  will not start again current update is complete.";
 		return;
 	}
-	else
+
+	qDebug() << "[Quasars] Updating quasars catalog...";
+	startDownload(updateUrl);
+}
+
+void Quasars::deleteDownloadProgressBar()
+{
+	disconnect(this, SLOT(updateDownloadProgress(qint64,qint64)));
+
+	if (progressBar)
 	{
-		qDebug() << "[Quasars] Starting update...";
+		StelApp::getInstance().removeProgressBar(progressBar);
+		progressBar = Q_NULLPTR;
+	}
+}
+
+void Quasars::startDownload(QString urlString)
+{
+	QUrl url(urlString);
+	if (!url.isValid() || url.isRelative() || !url.scheme().startsWith("http", Qt::CaseInsensitive))
+	{
+		qWarning() << "[Quasars] Invalid URL:" << urlString;
+		return;
 	}
 
-	lastUpdate = QDateTime::currentDateTime();
-	conf->setValue("Quasars/last_update", lastUpdate.toString(Qt::ISODate));
+	if (progressBar == Q_NULLPTR)
+		progressBar = StelApp::getInstance().addProgressBar();
+	progressBar->setValue(0);
+	progressBar->setRange(0, 0);
+
+	connect(networkManager, SIGNAL(finished(QNetworkReply*)), this, SLOT(downloadComplete(QNetworkReply*)));
+	QNetworkRequest request;
+	request.setUrl(QUrl(updateUrl));
+	request.setRawHeader("User-Agent", StelUtils::getUserAgentString().toUtf8());
+	#if QT_VERSION >= 0x050600
+	request.setAttribute(QNetworkRequest::FollowRedirectsAttribute, true);
+	#endif
+	downloadReply = networkManager->get(request);
+	connect(downloadReply, SIGNAL(downloadProgress(qint64,qint64)), this, SLOT(updateDownloadProgress(qint64,qint64)));
 
 	updateState = Quasars::Updating;
 	emit(updateStateChanged(updateState));
-
-	if (progressBar==Q_NULLPTR)
-		progressBar = StelApp::getInstance().addProgressBar();
-
-	progressBar->setValue(0);
-	progressBar->setRange(0, 100);
-	progressBar->setFormat("Update quasars");
-
-	QNetworkRequest request;
-	request.setUrl(QUrl(updateUrl));
-	request.setRawHeader("User-Agent", QString("Mozilla/5.0 (Stellarium Quasars Plugin %1; http://stellarium.org/)").arg(QUASARS_PLUGIN_VERSION).toUtf8());
-	downloadMgr->get(request);
-
-	updateState = Quasars::CompleteUpdates;
-	emit(updateStateChanged(updateState));
-	emit(jsonUpdateComplete());
 }
 
-void Quasars::updateDownloadComplete(QNetworkReply* reply)
+void Quasars::updateDownloadProgress(qint64 bytesReceived, qint64 bytesTotal)
 {
-	// check the download worked, and save the data to file if this is the case.
-	if (reply->error() == QNetworkReply::NoError && reply->bytesAvailable()>0)
+	if (progressBar == Q_NULLPTR)
+		return;
+
+	int currentValue = 0;
+	int endValue = 0;
+
+	if (bytesTotal > -1 && bytesReceived <= bytesTotal)
 	{
-		// download completed successfully.
-		QString jsonFilePath = StelFileMgr::findFile("modules/Quasars", StelFileMgr::Flags(StelFileMgr::Writable|StelFileMgr::Directory)) + "/quasars.json";
-		if (jsonFilePath.isEmpty())
+		//Round to the greatest possible derived unit
+		while (bytesTotal > 1024)
 		{
-			qWarning() << "[Quasars] Cannot write JSON data to file:" << QDir::toNativeSeparators(jsonFilePath);
-			return;
+			bytesReceived = std::floor(bytesReceived / 1024.);
+			bytesTotal    = std::floor(bytesTotal / 1024.);
 		}
+		currentValue = bytesReceived;
+		endValue = bytesTotal;
+	}
+
+	progressBar->setValue(currentValue);
+	progressBar->setRange(0, endValue);
+}
+
+void Quasars::downloadComplete(QNetworkReply *reply)
+{
+	if (reply == Q_NULLPTR)
+		return;
+
+	disconnect(networkManager, SIGNAL(finished(QNetworkReply*)), this, SLOT(downloadComplete(QNetworkReply*)));
+
+	#if QT_VERSION < 0x050600
+	int statusCode = reply->attribute(QNetworkRequest::HttpStatusCodeAttribute).toInt();
+	if (statusCode == 301 || statusCode == 302 || statusCode == 307)
+	{
+		QUrl rawUrl = reply->attribute(QNetworkRequest::RedirectionTargetAttribute).toUrl();
+		QUrl redirectUrl(rawUrl.toString(QUrl::RemoveQuery));
+		qDebug() << "[Quasars] The query has been redirected to" << redirectUrl.toString();
+		updateUrl = redirectUrl.toString();
+		conf->setValue("Quasars/url", updateUrl);
+		reply->deleteLater();
+		downloadReply = Q_NULLPTR;
+		startDownload(redirectUrl.toString());
+		return;
+	}
+	#endif
+
+	deleteDownloadProgressBar();
+
+	if (reply->error() || reply->bytesAvailable()==0)
+	{
+		qWarning() << "[Quasars] Download error: While trying to access"
+			   << reply->url().toString()
+			   << "the following error occured:"
+			   << reply->errorString();
+
+		reply->deleteLater();
+		downloadReply = Q_NULLPTR;
+		return;
+	}
+
+	// download completed successfully.
+	try
+	{
+		QString jsonFilePath = StelFileMgr::findFile("modules/Quasars", StelFileMgr::Flags(StelFileMgr::Writable|StelFileMgr::Directory)) + "/quasars.json";
 		QFile jsonFile(jsonFilePath);
 		if (jsonFile.exists())
 			jsonFile.remove();
 
-		if(jsonFile.open(QIODevice::WriteOnly | QIODevice::Text))
+		if (jsonFile.open(QIODevice::WriteOnly | QIODevice::Text))
 		{
 			jsonFile.write(reply->readAll());
 			jsonFile.close();
 		}
-	}
-	else
-		qWarning() << "[Quasars] FAILED to download" << reply->url() << " Error: " << reply->errorString();
 
-	if (progressBar)
-	{
-		progressBar->setValue(100);
-		StelApp::getInstance().removeProgressBar(progressBar);
-		progressBar = Q_NULLPTR;
+		updateState = Quasars::CompleteUpdates;
+
+		lastUpdate = QDateTime::currentDateTime();
+		conf->setValue("Quasars/last_update", lastUpdate.toString(Qt::ISODate));
 	}
+	catch (std::runtime_error &e)
+	{
+		qWarning() << "[Quasars] Cannot write JSON data to file:" << e.what();
+		updateState = Quasars::DownloadError;
+	}
+
+	emit(updateStateChanged(updateState));
+	emit(jsonUpdateComplete());
+
+	reply->deleteLater();
+	downloadReply = Q_NULLPTR;
+
+	readJsonFile();
 }
 
 void Quasars::displayMessage(const QString& message, const QString hexColor)
@@ -731,6 +827,7 @@ Vec3f Quasars::getMarkerColor()
 void Quasars::setMarkerColor(const Vec3f &c)
 {
 	Quasar::markerColor = c;
+	emit quasarsColorChanged(c);
 }
 
 void Quasars::reloadCatalog(void)
