@@ -17,8 +17,8 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef _REMOTECONTROLDIALOG_HPP_
-#define _REMOTECONTROLDIALOG_HPP_
+#ifndef REMOTECONTROLDIALOG_HPP
+#define REMOTECONTROLDIALOG_HPP
 
 #include "StelDialog.hpp"
 #include "StelGui.hpp"
@@ -58,4 +58,4 @@ private slots:
 };
 
 
-#endif /* _REMOTECONTROLDIALOG_HPP_ */
+#endif /* REMOTECONTROLDIALOG_HPP */
