@@ -17,8 +17,8 @@
  * Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA  02110-1335, USA.
  */
 
-#ifndef SYNCPROTOCOL_HPP_
-#define SYNCPROTOCOL_HPP_
+#ifndef SYNCPROTOCOL_HPP
+#define SYNCPROTOCOL_HPP
 
 #include <QByteArray>
 #include <QDataStream>
