@@ -29,15 +29,15 @@
 #include "StelPropertyMgr.hpp"
 
 RemoteSyncDialog::RemoteSyncDialog()
-	: rs(Q_NULLPTR)
+	: StelDialog("RemoteSync")
+	, rs(Q_NULLPTR)
 {
 	ui = new Ui_remoteSyncDialog();
-	dialogName="RemoteSync";
 }
 
 RemoteSyncDialog::~RemoteSyncDialog()
 {
-	delete ui;
+	delete ui; ui=Q_NULLPTR;
 }
 
 void RemoteSyncDialog::retranslate()
@@ -54,12 +54,14 @@ void RemoteSyncDialog::createDialogContent()
 	rs = GETSTELMODULE(RemoteSync);
 	ui->setupUi(dialog);
 
-#ifdef Q_OS_WIN
-	//Kinetic scrolling for tablet pc and pc
-	QList<QWidget *> addscroll;
-	addscroll << ui->aboutTextBrowser;
-	installKineticScrolling(addscroll);
-#endif
+	// Kinetic scrolling
+	kineticScrollingList << ui->aboutTextBrowser;
+	StelGui* gui= dynamic_cast<StelGui*>(StelApp::getInstance().getGui());
+	if (gui)
+	{
+		enableKineticScrolling(gui->getFlagUseKineticScrolling());
+		connect(gui, SIGNAL(flagUseKineticScrollingChanged(bool)), this, SLOT(enableKineticScrolling(bool)));
+	}
 
 	ui->pushButtonSelectProperties->setText(QChar(0x2192));
 	ui->pushButtonDeselectProperties->setText(QChar(0x2190));
