@@ -70,7 +70,7 @@ StelPluginInfo SatellitesStelPluginInterface::getPluginInfo() const
 	info.id = "Satellites";
 	info.displayedName = N_("Satellites");
 	info.authors = "Matthew Gates, Jose Luis Canales";
-	info.contact = "http://stellarium.org/";
+	info.contact = "https://stellarium.org/";
 	info.description = N_("Prediction of artificial satellite positions in Earth orbit based on NORAD TLE data");
 	info.version = SATELLITES_PLUGIN_VERSION;
 	info.license = SATELLITES_PLUGIN_LICENSE;
@@ -745,7 +745,17 @@ const QString Satellites::readCatalogVersion()
 	}
 
 	QVariantMap map;
-	map = StelJsonParser::parse(&satelliteJsonFile).toMap();
+	try
+	{
+		map = StelJsonParser::parse(&satelliteJsonFile).toMap();
+		satelliteJsonFile.close();
+	}
+	catch (std::runtime_error &e)
+	{
+		qDebug() << "[Satellites] File format is wrong! Error: " << e.what();
+		return jsonVersion;
+	}
+
 	if (map.contains("creator"))
 	{
 		QString creator = map.value("creator").toString();
@@ -756,7 +766,6 @@ const QString Satellites::readCatalogVersion()
 		}
 	}
 
-	satelliteJsonFile.close();
 	//qDebug() << "[Satellites] catalog version from file:" << jsonVersion;
 	return jsonVersion;
 }
@@ -796,8 +805,16 @@ QVariantMap Satellites::loadDataMap(QString path)
 		qWarning() << "[Satellites] cannot open " << QDir::toNativeSeparators(path);
 	else
 	{
-		map = StelJsonParser::parse(&jsonFile).toMap();
-		jsonFile.close();
+		try
+		{
+			map = StelJsonParser::parse(&jsonFile).toMap();
+			jsonFile.close();
+		}
+		catch (std::runtime_error &e)
+		{
+			qDebug() << "[Satellites] File format is wrong! Error: " << e.what();
+			return QVariantMap();
+		}
 	}
 	return map;
 }
@@ -1194,10 +1211,11 @@ void Satellites::setUpdateFrequencyHours(int hours)
 
 void Satellites::checkForUpdate(void)
 {
-	if (updatesEnabled && updateState != Updating
-	    && lastUpdate.addSecs(updateFrequencyHours * 3600) <= QDateTime::currentDateTime()
-	    && downloadMgr->networkAccessible()==QNetworkAccessManager::Accessible)
+	if (updatesEnabled && (updateState != Updating)
+	    && (lastUpdate.addSecs(updateFrequencyHours * 3600) <= QDateTime::currentDateTime()))
+	{
 		updateFromOnlineSources();
+	}
 }
 
 void Satellites::updateFromOnlineSources()
@@ -1357,7 +1375,7 @@ void Satellites::saveDownloadedUpdate(QNetworkReply* reply)
 	if (progressBar)
 	{
 		StelApp::getInstance().removeProgressBar(progressBar);
-		progressBar = 0;
+		progressBar = Q_NULLPTR;
 	}
 	
 	// All files have been downloaded, finish the update
@@ -1787,8 +1805,7 @@ bool Satellites::checkJsonFileFormat()
 	}
 	catch (std::runtime_error& e)
 	{
-		qDebug() << "[Satellites] file format is wrong!";
-		qDebug() << "[Satellites] error:" << e.what();
+		qDebug() << "[Satellites] File format is wrong! Error:" << e.what();
 		return false;
 	}
 
@@ -2095,10 +2112,28 @@ void Satellites::translations()
 	N_("International Gamma-Ray Astrophysics Laboratory");
 	// TRANSLATORS: Satellite description.
 	N_("The Gamma-Ray Observatory");
+	// TRANSLATORS: Satellite description.
+	N_("The Microvariability and Oscillations of Stars telescope");
+	// TRANSLATORS: Satellite description.
+	N_("The Interface Region Imaging Spectrograph");
+	// TRANSLATORS: Satellite description.
+	N_("The Spectroscopic Planet Observatory for Recognition of Interaction of Atmosphere");
+	// TRANSLATORS: Satellite description.
+	M_("Nuclear Spectroscopic Telescope Array");
+	// TRANSLATORS: Satellite description.
+	N_("The Dark Matter Particle Explorer");
+	// TRANSLATORS: Satellite description.
+	N_("Arcsecond Space Telescope Enabling Research in Astrophysics");
+	// TRANSLATORS: Satellite description.
+	N_("Reuven Ramaty High Energy Solar Spectroscopic Imager");
+	// TRANSLATORS: Satellite description.
+	N_("The Chandra X-ray Observatory");
 
 	// Satellite names - a few famous objects only
 	// TRANSLATORS: Satellite name: International Space Station
 	N_("ISS (ZARYA)");
+	// TRANSLATORS: Satellite name: International Space Station
+	N_("ISS");
 	// TRANSLATORS: Satellite name: Hubble Space Telescope
 	N_("HST");
 	// TRANSLATORS: Satellite name: Spektr-R Space Observatory (or RadioAstron)
