@@ -18,8 +18,8 @@
  * Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA  02110-1335, USA.
  */
 
-#ifndef _S3DSCENE_HPP_
-#define _S3DSCENE_HPP_
+#ifndef S3DSCENE_HPP
+#define S3DSCENE_HPP
 
 #include "StelOBJ.hpp"
 #include "StelTextureTypes.hpp"
@@ -184,4 +184,4 @@ private:
 	static void finalizeTexture(StelTextureSP& tex);
 };
 
-#endif // _S3DSCENE_HPP_
+#endif // S3DSCENE_HPP
