@@ -20,14 +20,14 @@
 
 #include "StoredViewDialog.hpp"
 #include "StoredViewDialog_p.hpp"
-#include "Scenery3dMgr.hpp"
+#include "Scenery3d.hpp"
 
 #include "StelApp.hpp"
 #include "StelGui.hpp"
 #include "StelModuleMgr.hpp"
 #include "StelTranslator.hpp"
 
-StoredViewDialog::StoredViewDialog(QObject *parent) : StelDialog("Scenery3dViews", parent), mgr(NULL), viewModel(NULL)
+StoredViewDialog::StoredViewDialog(QObject *parent) : StelDialog("Scenery3dViews", parent), mgr(Q_NULLPTR), viewModel(Q_NULLPTR)
 {
 	ui = new Ui_storedViewDialogForm;
 }
@@ -49,7 +49,7 @@ void StoredViewDialog::createDialogContent()
 	connect(ui->closeStelWindow, &QPushButton::clicked, this, &StelDialog::close);
 	connect(ui->TitleBar, SIGNAL(movedTo(QPoint)), this, SLOT(handleMovedTo(QPoint)));
 
-	mgr = GETSTELMODULE(Scenery3dMgr);
+	mgr = GETSTELMODULE(Scenery3d);
 	Q_ASSERT(mgr);
 
 	connect(ui->pushButtonAddView, &QPushButton::clicked, this, &StoredViewDialog::addUserView);
@@ -70,7 +70,7 @@ void StoredViewDialog::createDialogContent()
 	ui->listView->setModel(viewModel);
 	connect(ui->listView->selectionModel(), &QItemSelectionModel::currentChanged, this, &StoredViewDialog::updateViewSelection);
 
-	connect(mgr, &Scenery3dMgr::currentSceneChanged, viewModel, &StoredViewModel::setScene);
+	connect(mgr, &Scenery3d::currentSceneChanged, viewModel, &StoredViewModel::setScene);
 	connect(viewModel, &QAbstractItemModel::modelReset, this, &StoredViewDialog::resetViewSelection);
 	viewModel->setScene(mgr->getCurrentScene());
 }
