@@ -56,7 +56,7 @@ StelPluginInfo SolarSystemEditorStelPluginInterface::getPluginInfo() const
 	info.id = "SolarSystemEditor";
 	info.displayedName = N_("Solar System Editor");
 	info.authors = "Bogdan Marinov";
-	info.contact = "http://stellarium.org";
+	info.contact = STELLARIUM_URL;
 	info.description = N_("An interface for adding asteroids and comets to Stellarium. It can download object lists from the Minor Planet Center's website and perform searches in its online database.");
 	info.version = SOLARSYSTEMEDITOR_PLUGIN_VERSION;
 	info.license = SOLARSYSTEMEDITOR_PLUGIN_LICENSE;
