@@ -23,7 +23,7 @@
 
 #include "TelescopeClientINDI.hpp"
 
-class testTelescopeControl_INDI : public QObject
+class TestTelescopeControl_INDI : public QObject
 {
     Q_OBJECT
 
