@@ -23,8 +23,8 @@
  * Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA  02110-1335, USA.
  */
 
-#ifndef _TELESCOPE_HPP_
-#define _TELESCOPE_HPP_
+#ifndef TELESCOPECLIENT_HPP
+#define TELESCOPECLIENT_HPP
 
 #include <QHostAddress>
 #include <QHostInfo>
@@ -222,4 +222,4 @@ private slots:
 	void socketFailed(QAbstractSocket::SocketError socketError);
 };
 
-#endif // _TELESCOPE_HPP_
+#endif // TELESCOPECLIENT_HPP
