@@ -413,7 +413,7 @@ void TelescopeConfigurationDialog::buttonSavePressed()
 
 	QString host = ui->lineEditHostName->text();
 
-	if(host.isEmpty() || !validateHost(host))
+	if(host.isEmpty()) // Remove validation of hostname
 		return;
 	
 	int delay = MICROSECONDS_FROM_SECONDS(ui->doubleSpinBoxTelescopeDelay->value());
@@ -492,18 +492,3 @@ void TelescopeConfigurationDialog::deviceModelSelected(const QString& deviceMode
 	ui->labelDeviceModelDescription->setText(q_(telescopeManager->getDeviceModels().value(deviceModelName).description));
 	ui->doubleSpinBoxTelescopeDelay->setValue(SECONDS_FROM_MICROSECONDS(telescopeManager->getDeviceModels().value(deviceModelName).defaultDelay));
 }
-
-bool TelescopeConfigurationDialog::validateHost(QString hostName)
-{
-    // Simple validation by ping
-    int exitCode;
-#ifdef Q_OS_WIN
-    // WTF? It's not working anymore!
-    //exitCode = QProcess::execute("ping", QStringList() << "-n 1" << hostName);
-    exitCode = 0;
-#else
-    exitCode = QProcess::execute("ping", QStringList() << "-c1" << hostName);
-#endif
-    return (0 == exitCode);
-    //TODO: Add debug if host not alive?
-}
