@@ -345,7 +345,7 @@ public:
 	void setSkyBackgroundColor(Vec3f color) { skyBackgroundColor=color; }
 
 	//! Get the sky background color. Everything else than black creates a work of art!
-	Vec3f getSkyBackgroundColor() { return skyBackgroundColor; }
+	Vec3f getSkyBackgroundColor() const { return skyBackgroundColor; }
 
 
 protected:
@@ -509,8 +509,8 @@ private:
 				//note: the old code seems to have ignored double clicks
 				// and handled them the same as normal mouse presses
 				//if we ever want to handle double clicks, switch out these lines
-				//t = QEvent::MouseButtonDblClick;
-				t = QEvent::MouseButtonPress;
+				t = QEvent::MouseButtonDblClick;
+				//t = QEvent::MouseButtonPress;
 				break;
 			default:
 				//warn in release and assert in debug
@@ -570,7 +570,6 @@ StelMainView::StelMainView(QSettings* settings)
 	  screenShotPrefix("stellarium-"),
 	  screenShotDir(""),
 	  flagCursorTimeout(false),
-	  flagUseButtonsBackground(true),
 	  lastEventTimeSec(0.0),
 	  minfps(1.f),
 	  maxfps(10000.f)
@@ -870,7 +869,6 @@ void StelMainView::init()
 	setCursorTimeout(conf->value("gui/mouse_cursor_timeout", 10.f).toFloat());
 	setMaxFps(conf->value("video/maximum_fps",10000.f).toFloat());
 	setMinFps(conf->value("video/minimum_fps",10000.f).toFloat());
-	setFlagUseButtonsBackground(conf->value("gui/flag_show_buttons_background", true).toBool());
 	setSkyBackgroundColor(StelUtils::strToVec3f(configuration->value("color/sky_background_color", "0,0,0").toString()));
 
 	// XXX: This should be done in StelApp::init(), unfortunately for the moment we need to init the gui before the
@@ -1008,7 +1006,7 @@ void StelMainView::processOpenGLdiagnosticsAndWarnings(QSettings *conf, QOpenGLC
 				openGLerror=true;
 				qDebug() << "This is not enough: we need DirectX9 with vs_2_0 and ps_3_0 or later.";
 				qDebug() << "You should update graphics drivers, graphics hardware, or use the --mesa-mode option.";
-				qDebug() << "Else, please try to use an older version like 0.12.5, and try with --safe-mode";
+				qDebug() << "Else, please try to use an older version like 0.12.9, and try with --safe-mode";
 
 				if (conf->value("main/ignore_opengl_warning", false).toBool())
 				{
@@ -1059,7 +1057,7 @@ void StelMainView::processOpenGLdiagnosticsAndWarnings(QSettings *conf, QOpenGLC
 				openGLerror=true;
 				qDebug() << "This is not enough: we need Mesa 10.0 or later.";
 				qDebug() << "You should update graphics drivers or graphics hardware.";
-				qDebug() << "Else, please try to use an older version like 0.12.5, and try there with --safe-mode";
+				qDebug() << "Else, please try to use an older version like 0.12.9, and try there with --safe-mode";
 
 				if (conf->value("main/ignore_opengl_warning", false).toBool())
 				{
@@ -1114,8 +1112,12 @@ void StelMainView::processOpenGLdiagnosticsAndWarnings(QSettings *conf, QOpenGLC
 		{
 			openGLerror=true;
 			qDebug() << "This is not enough: we need GLSL1.30 or later.";
+			#ifdef Q_OS_WIN
 			qDebug() << "You should update graphics drivers, graphics hardware, or use the --mesa-mode option.";
-			qDebug() << "Else, please try to use an older version like 0.12.5, and try there with --safe-mode";
+			#else
+			qDebug() << "You should update graphics drivers or graphics hardware.";
+			#endif
+			qDebug() << "Else, please try to use an older version like 0.12.9, and try there with --safe-mode";
 
 			if (conf->value("main/ignore_opengl_warning", false).toBool())
 			{
@@ -1430,6 +1432,8 @@ void StelMainView::doScreenshot(void)
 	float pixelRatio = QOpenGLContext::currentContext()->screen()->devicePixelRatio();
 	int imgWidth =stelScene->width();
 	int imgHeight=stelScene->height();
+	bool nightModeWasEnabled=nightModeEffect->isEnabled();
+	nightModeEffect->setEnabled(false);
 	if (flagUseCustomScreenshotSize)
 	{
 		// Borrowed from Scenery3d renderer: determine maximum framebuffer size as minimum of texture, viewport and renderbuffer size
@@ -1528,12 +1532,24 @@ void StelMainView::doScreenshot(void)
 	// reset viewport and GUI
 	StelApp::getInstance().getCore()->setCurrentStelProjectorParams(pParams);
 	customScreenshotMagnification=1.0f;
+	nightModeEffect->setEnabled(nightModeWasEnabled);
 	stelScene->setSceneRect(0, 0, pParams.viewportXywh[2], pParams.viewportXywh[3]);
 	rootItem->setSize(QSize(pParams.viewportXywh[2], pParams.viewportXywh[3]));
 	dynamic_cast<StelGui*>(gui)->getSkyGui()->setGeometry(0, 0, pParams.viewportXywh[2], pParams.viewportXywh[3]);
 	dynamic_cast<StelGui*>(gui)->forceRefreshGui();
 #endif
 
+	if (nightModeWasEnabled)
+	{
+		for (int row=0; row<im.height(); ++row)
+			for (int col=0; col<im.width(); ++col)
+			{
+				QRgb rgb=im.pixel(col, row);
+				int gray=qGray(rgb);
+				im.setPixel(col, row, qRgb(gray, 0, 0));
+			}
+
+	}
 	if (flagInvertScreenShotColors)
 		im.invertPixels();
 
@@ -1595,7 +1611,7 @@ void StelMainView::doScreenshot(void)
 	}
 }
 
-QPoint StelMainView::getMousePos()
+QPoint StelMainView::getMousePos() const
 {
 	return glWidget->mapFromGlobal(QCursor::pos());
 }
@@ -1628,7 +1644,7 @@ void StelMainView::setSkyBackgroundColor(Vec3f color)
 }
 
 // Get the sky background color. Everything else than black creates a work of art!
-Vec3f StelMainView::getSkyBackgroundColor()
+Vec3f StelMainView::getSkyBackgroundColor() const
 {
 	return rootItem->getSkyBackgroundColor();
 }
