@@ -20,8 +20,8 @@
  * Implementation: 2010-03-23 GZ=Georg Zotti, Georg.Zotti@univie.ac.at
  * 2010-12 FC split into 2 classes, implemented Refraction */
 
-#ifndef _REFRACTIONEXTINCTION_HPP_
-#define _REFRACTIONEXTINCTION_HPP_
+#ifndef REFRACTIONEXTINCTION_HPP
+#define REFRACTIONEXTINCTION_HPP
 // USABILITY: added 3 more flags/switches in GUI:
 // Temperature [C] [influences refraction]
 // Pressure [mbar]  [influences refraction]
@@ -92,7 +92,6 @@ public:
 	void setUndergroundExtinctionMode(UndergroundExtinctionMode mode) {undergroundExtinctionMode=mode;}
 	UndergroundExtinctionMode getUndergroundExtinctionMode() const {return undergroundExtinctionMode;}
 	
-private:
 	//! airmass computation for @param cosZ = cosine of zenith angle z (=sin(altitude)!).
 	//! The default (@param apparent_z = true) is computing airmass from observed altitude, following Rozenberg (1966) [X(90)~40].
 	//! if (@param apparent_z = false), we have geometrical altitude and compute airmass from that,
@@ -102,6 +101,7 @@ private:
 	//! Rozenberg is infinite at Z=92.17 deg, Young at Z=93.6 deg, so this function RETURNS SUBHORIZONTAL_AIRMASS BELOW -2 DEGREES!
 	float airmass(float cosZ, const bool apparent_z=true) const;
 
+private:
 	//! k, magnitudes/airmass, in [0.00, ... 1.00], (default 0.20).
 	float ext_coeff;
 
@@ -193,4 +193,4 @@ private:
 	Mat4f invertPostTransfoMatf;
 };
 
-#endif  // _REFRACTIONEXTINCTION_HPP_
+#endif  // REFRACTIONEXTINCTION_HPP
