@@ -17,8 +17,8 @@
  * Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA  02110-1335, USA.
  */
 
-#ifndef _STELAPP_HPP_
-#define _STELAPP_HPP_
+#ifndef STELAPP_HPP
+#define STELAPP_HPP
 
 #include <QString>
 #include <QObject>
@@ -73,6 +73,8 @@ class StelApp : public QObject
 	Q_PROPERTY(bool flagUseAzimuthFromSouth READ getFlagSouthAzimuthUsage   WRITE setFlagSouthAzimuthUsage   NOTIFY flagUseAzimuthFromSouthChanged)
 	Q_PROPERTY(bool flagUseCCSDesignation   READ getFlagUseCCSDesignation   WRITE setFlagUseCCSDesignation   NOTIFY flagUseCCSDesignationChanged)
 	Q_PROPERTY(bool flagUseFormattingOutput READ getFlagUseFormattingOutput WRITE setFlagUseFormattingOutput NOTIFY flagUseFormattingOutputChanged)
+	Q_PROPERTY(int  screenFontSize          READ getScreenFontSize          WRITE setScreenFontSize          NOTIFY screenFontSizeChanged)
+	Q_PROPERTY(int  guiFontSize             READ getGuiFontSize             WRITE setGuiFontSize             NOTIFY guiFontSizeChanged)
 
 public:
 	friend class StelAppGraphicsWidget;
@@ -110,63 +112,63 @@ public:
 
 	//! Get the module manager to use for accessing any module loaded in the application.
 	//! @return the module manager.
-	StelModuleMgr& getModuleMgr() {return *moduleMgr;}
+	StelModuleMgr& getModuleMgr() const {return *moduleMgr;}
 
 	//! Get the corresponding module or Q_NULLPTR if can't find it.
 	//! This is a shortcut for getModleMgr().getModule().
 	//! @return the module pointer.
-	StelModule* getModule(const QString& moduleID);
+	StelModule* getModule(const QString& moduleID) const;
 
 	//! Get the locale manager to use for i18n & date/time localization.
 	//! @return the font manager to use for loading fonts.
-	StelLocaleMgr& getLocaleMgr() {return *localeMgr;}
+	StelLocaleMgr& getLocaleMgr() const {return *localeMgr;}
 
 	//! Get the sky cultures manager.
 	//! @return the sky cultures manager
-	StelSkyCultureMgr& getSkyCultureMgr() {return *skyCultureMgr;}
+	StelSkyCultureMgr& getSkyCultureMgr() const {return *skyCultureMgr;}
 
 	//! Get the texture manager to use for loading textures.
 	//! @return the texture manager to use for loading textures.
-	StelTextureMgr& getTextureManager() {return *textureMgr;}
+	StelTextureMgr& getTextureManager() const {return *textureMgr;}
 
 	//! Get the Location manager to use for managing stored locations
 	//! @return the Location manager to use for managing stored locations
-	StelLocationMgr& getLocationMgr() {return *planetLocationMgr;}
+	StelLocationMgr& getLocationMgr() const {return *planetLocationMgr;}
 
 	//! Get the StelObject manager to use for querying from all stellarium objects.
 	//! @return the StelObject manager to use for querying from all stellarium objects 	.
-	StelObjectMgr& getStelObjectMgr() {return *stelObjectMgr;}
+	StelObjectMgr& getStelObjectMgr() const {return *stelObjectMgr;}
 
-	StelSkyLayerMgr& getSkyImageMgr() {return *skyImageMgr;}
+	StelSkyLayerMgr& getSkyImageMgr() const {return *skyImageMgr;}
 
 	//! Get the audio manager
-	StelAudioMgr* getStelAudioMgr() {return audioMgr;}
+	StelAudioMgr* getStelAudioMgr() const {return audioMgr;}
 
 	//! Get the actions manager to use for managing and editing actions
-	StelActionMgr* getStelActionManager() {return actionMgr;}
+	StelActionMgr* getStelActionManager() const {return actionMgr;}
 
 	//! Return the property manager
-	StelPropertyMgr* getStelPropertyManager() {return propMgr;}
+	StelPropertyMgr* getStelPropertyManager() const {return propMgr;}
 
 	//! Get the video manager
-	StelVideoMgr* getStelVideoMgr() {return videoMgr;}
+	StelVideoMgr* getStelVideoMgr() const {return videoMgr;}
 
 	//! Get the core of the program.
 	//! It is the one which provide the projection, navigation and tone converter.
 	//! @return the StelCore instance of the program
-	StelCore* getCore() {return core;}
+	StelCore* getCore() const {return core;}
 
 	//! Get the common instance of QNetworkAccessManager used in stellarium
-	QNetworkAccessManager* getNetworkAccessManager() {return networkAccessManager;}
+	QNetworkAccessManager* getNetworkAccessManager() const {return networkAccessManager;}
 
 	//! Update translations, font for GUI and sky everywhere in the program.
 	void updateI18n();
 
 	//! Return the main configuration options
-	QSettings* getSettings() {return confSettings;}
+	QSettings* getSettings() const {return confSettings;}
 
 	//! Return the currently used style
-	QString getCurrentStelStyle() {return "color";}
+	const QString getCurrentStelStyle() const {return "color";}
 
 	//! Update all object according to the deltaTime in seconds.
 	void update(double deltaTime);
@@ -187,9 +189,14 @@ public:
 	float getGlobalScalingRatio() const {return globalScalingRatio;}
 	void setGlobalScalingRatio(float r) {globalScalingRatio=r;}
 
-	//! Get the size of font
-	int getBaseFontSize() const { return baseFontSize; }
-	void setBaseFontSize(int s) { baseFontSize=s; }
+	//! Get the fontsize used for screen text.
+	int getScreenFontSize() const { return screenFontSize; }
+	//! Change screen font size.
+	void setScreenFontSize(int s);
+	//! Get the principal font size used for GUI panels.
+	int getGuiFontSize() const;
+	//! change GUI font size.
+	void setGuiFontSize(int s);
 
 	//! Get the GUI instance implementing the abstract GUI interface.
 	StelGuiBase* getGui() const {return stelGui;}
@@ -199,9 +206,9 @@ public:
 
 #ifndef DISABLE_SCRIPTING
 	//! Get the script API proxy (for signal handling)
-	StelMainScriptAPIProxy* getMainScriptAPIProxy() {return scriptAPIProxy;}
+	StelMainScriptAPIProxy* getMainScriptAPIProxy() const {return scriptAPIProxy;}
 	//! Get the script manager
-	StelScriptMgr& getScriptMgr() {return *scriptMgr;}
+	StelScriptMgr& getScriptMgr() const {return *scriptMgr;}
 #endif
 
 	static void initStatic();
@@ -220,7 +227,7 @@ public:
 	QString getViewportEffect() const;
 
 	//! Dump diagnostics about action call priorities
-	void dumpModuleActionPriorities(StelModule::StelModuleActionName actionName);
+	void dumpModuleActionPriorities(StelModule::StelModuleActionName actionName) const;
 	
 	///////////////////////////////////////////////////////////////////////////
 	// Scriptable methods
@@ -257,6 +264,11 @@ public slots:
 	//! @return the FPS averaged on the last second
 	float getFps() const {return fps;}
 
+	//! Set global application font.
+	//! To retrieve, you can use QGuiApplication::font().
+	//! emits fontChanged(font)
+	void setAppFont(QFont font);
+
 	//! Returns the default FBO handle, to be used when StelModule instances want to release their own FBOs.
 	//! Note that this is usually not the same as QOpenGLContext::defaultFramebufferObject(),
 	//! so use this call instead of the Qt version!
@@ -288,6 +300,9 @@ signals:
 	void flagUseFormattingOutputChanged(bool);
 	void colorSchemeChanged(const QString&);
 	void languageChanged();
+	void screenFontSizeChanged(int);
+	void guiFontSizeChanged(int);
+	void fontChanged(QFont);
 
 	//! Called just after a progress bar is added.
 	void progressBarAdded(const StelProgressController*);
@@ -418,7 +433,7 @@ private:
 
 	QList<StelProgressController*> progressControllers;
 
-	int baseFontSize;	
+	int screenFontSize;
 
 	// Framebuffer object used for viewport effects.
 	QOpenGLFramebufferObject* renderBuffer;
@@ -438,4 +453,4 @@ private:
 
 };
 
-#endif // _STELAPP_HPP_
+#endif // STELAPP_HPP
