@@ -18,8 +18,8 @@
  * Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA  02110-1335, USA.
  */
 
-#ifndef _STELCORE_HPP_
-#define _STELCORE_HPP_
+#ifndef STELCORE_HPP
+#define STELCORE_HPP
 
 #include "StelProjector.hpp"
 #include "StelProjectorType.hpp"
@@ -62,6 +62,7 @@ class StelCore : public QObject
 	//! Read-only property returning the localized projection name
 	Q_PROPERTY(QString currentProjectionNameI18n READ getCurrentProjectionNameI18n NOTIFY currentProjectionNameI18nChanged STORED false)
 	Q_PROPERTY(bool flagGravityLabels READ getFlagGravityLabels WRITE setFlagGravityLabels NOTIFY flagGravityLabelsChanged)
+	Q_PROPERTY(QString currentTimeZone READ getCurrentTimeZone WRITE setCurrentTimeZone NOTIFY currentTimeZoneChanged)
 
 public:
 
@@ -142,6 +143,7 @@ public:
 		IslamSadiqQureshi,                  //!< Islam, Sadiq & Qureshi (2008 + revisited 2013) algorithm for DeltaT (6 polynomials)
 		KhalidSultanaZaidi,                 //!< M. Khalid, Mariam Sultana and Faheem Zaidi polynomial approximation of time period 1620-2013 (2014)
 		StephensonMorrisonHohenkerk2016,    //!< Stephenson, Morrison, Hohenkerk (2016) RSPA paper provides spline fit to observations for -720..2016 and else parabolic fit.
+		Henriksson2017,			    //!< Henriksson (2017) algorithm for DeltaT (The solution for Schoch formula for DeltaT (1931), but with ndot=-30.128"/cy^2)
 		Custom                              //!< User defined coefficients for quadratic equation for DeltaT
 	};
 
@@ -325,7 +327,7 @@ public:
 
 	//! Return the startup mode, can be "actual" (i.e. take current time from system),
 	//! "today" (take some time e.g. on the evening of today) or "preset" (completely preconfigured).
-	QString getStartupTimeMode();
+	QString getStartupTimeMode() const;
 	void setStartupTimeMode(const QString& s);
 
 	//! Get info about valid range for current algorithm for calculation of Delta-T
@@ -387,7 +389,7 @@ public slots:
 	//! they are aligned with the bottom of a 2d screen, or a 3d dome.
 	void setFlagGravityLabels(bool gravity);
 	//! return whether dome-aligned labels are in use
-	bool getFlagGravityLabels();
+	bool getFlagGravityLabels() const;
 	//! Set the offset rotation angle in degree to apply to gravity text (only if gravityLabels is set to false).
 	void setDefaultAngleForGravityText(float a);
 	//! Set the horizontal flip status.
@@ -543,7 +545,7 @@ public slots:
 	bool getIsTimeNow() const;
 
 	//! get the initial "today time" from the config file
-	QTime getInitTodayTime(void);
+	QTime getInitTodayTime(void) const;
 	//! set the initial "today time" from the config file
 	void setInitTodayTime(const QTime& time);
 	//! Set the preset sky time from a QDateTime
@@ -624,6 +626,9 @@ public slots:
 	//! Add one tropical year to the simulation time.
 	void addTropicalYear();
 
+	//! Add one calendric month to the simulation time.
+	void addCalendricMonth();
+
 	//! Add one Julian year to the simulation time.
 	void addJulianYear();
 	//! Add n Julian years to the simulation time.
@@ -660,6 +665,9 @@ public slots:
 	//! Subtract one tropical year to the simulation time.
 	void subtractTropicalYear();
 
+	//! Subtract one calendric month to the simulation time.
+	void subtractCalendricMonth();
+
 	//! Subtract one Julian year to the simulation time.
 	void subtractJulianYear();
 	//! Subtract n Julian years to the simulation time.
@@ -721,6 +729,8 @@ signals:
 	void locationChanged(StelLocation);
 	//! This signal is emitted whenever the targetted location changes
 	void targetLocationChanged(StelLocation);
+	//! This signal is emitted when the current timezone name is changed.
+	void currentTimeZoneChanged(QString);
 	//! This signal is emitted when the time rate has changed
 	void timeRateChanged(double rate);
 	//! This signal is emitted whenever the time is re-synced.
@@ -833,4 +843,4 @@ private:
 	bool de431Active;    // available and user-activated.
 };
 
-#endif // _STELCORE_HPP_
+#endif // STELCORE_HPP
