@@ -17,8 +17,8 @@
  * Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA  02110-1335, USA.
  */
 
-#ifndef _STELINIPARSER_HPP_
-#define _STELINIPARSER_HPP_
+#ifndef STELINIPARSER_HPP
+#define STELINIPARSER_HPP
 
 #include <QSettings>
 
