@@ -17,8 +17,8 @@
  * Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA  02110-1335, USA.
  */
 
-#ifndef _STELMODULEMGR_HPP_
-#define _STELMODULEMGR_HPP_
+#ifndef STELMODULEMGR_HPP
+#define STELMODULEMGR_HPP
 
 #include <QObject>
 #include <QMap>
@@ -72,10 +72,10 @@ public:
 	//! Get the corresponding module or Q_NULLPTR if can't find it.
 	//! @param moduleID the QObject name of the module instance, by convention it is equal to the class name.
 	//! @param noWarning if true, don't display any warning if the module is not found.
-	StelModule* getModule(const QString& moduleID, bool noWarning=false);
+	StelModule* getModule(const QString& moduleID, bool noWarning=false) const;
 
 	//! Get the list of all the currently registered modules
-	QList<StelModule*> getAllModules() {return modules.values();}
+	QList<StelModule*> getAllModules() const {return modules.values();}
 
 	//! Get the list of modules in the correct order for calling the given action
 	const QList<StelModule*>& getCallOrders(StelModule::StelModuleActionName action)
@@ -105,7 +105,7 @@ public:
 	//! Returns the list of all currently registered extensions.
 	//! If using this method, you probably also want to subscribe to
 	//! the extensionsAdded() signal to handle all possible initialization orders.
-	QObjectList getExtensionList() { return extensions; }
+	QObjectList getExtensionList() const { return extensions; }
 signals:
 	//! Called whenever new plugin extensions are added
 	void extensionsAdded(QObjectList newExtensions);
@@ -131,4 +131,4 @@ private:
 	bool pluginDescriptorListLoaded;
 };
 
-#endif // _STELMODULEMGR_HPP_
+#endif // STELMODULEMGR_HPP
