@@ -18,8 +18,8 @@
  * Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA  02110-1335, USA.
  */
 
-#ifndef _STELMOVEMENTMGR_HPP_
-#define _STELMOVEMENTMGR_HPP_
+#ifndef STELMOVEMENTMGR_HPP
+#define STELMOVEMENTMGR_HPP
 
 #include "StelModule.hpp"
 #include "StelProjector.hpp"
@@ -71,9 +71,11 @@ public:
 	//! MountGalactic and MountSupergalactic is currently only available via scripting API: core.clear("galactic") and core.clear("supergalactic")
 	// TODO: add others: MountEcliptical, MountEq2000, MountEcliptical2000 and implement proper variants.
 	enum MountMode { MountAltAzimuthal, MountEquinoxEquatorial, MountGalactic, MountSupergalactic};
+	Q_ENUM(MountMode)
 
 	//! Named constants for zoom operations.
 	enum ZoomingMode { ZoomOut=-1, ZoomNone=0, ZoomIn=1};
+	Q_ENUM(ZoomingMode)
 
 	StelMovementMgr(StelCore* core);
 	virtual ~StelMovementMgr();
@@ -119,7 +121,7 @@ public:
 
 	//! Get the zoom speed
 	// TODO: what are the units?
-	double getZoomSpeed() {return keyZoomSpeed;}
+	double getZoomSpeed() const {return keyZoomSpeed;}
 
 	//! Return the current up view vector in J2000 coordinates.
 	Vec3d getViewUpVectorJ2000() const;
@@ -135,6 +137,7 @@ public:
 	void setDragTriggerDistance(float d) {dragTriggerDistance=d;}
 
 public slots:
+	// UNUSED!
 	//! Toggle current mount mode between equatorial and altazimuthal
 	void toggleMountMode() {if (getMountMode()==MountAltAzimuthal) setMountMode(MountEquinoxEquatorial); else setMountMode(MountAltAzimuthal);}
 	//! Define whether we should use equatorial mount or altazimuthal
@@ -166,7 +169,7 @@ public slots:
 	//! Set whether auto zoom out will reset the viewing direction to the inital value
 	void setFlagAutoZoomOutResetsDirection(bool b) {if (flagAutoZoomOutResetsDirection != b) { flagAutoZoomOutResetsDirection = b; emit flagAutoZoomOutResetsDirectionChanged(b);}}
 	//! Get whether auto zoom out will reset the viewing direction to the inital value
-	bool getFlagAutoZoomOutResetsDirection(void) {return flagAutoZoomOutResetsDirection;}
+	bool getFlagAutoZoomOutResetsDirection(void) const {return flagAutoZoomOutResetsDirection;}
 
 	//! Get whether keys can control zoom
 	bool getFlagEnableZoomKeys() const {return flagEnableZoomKeys;}
@@ -230,10 +233,10 @@ public slots:
 	//! Return the initial default FOV in degree.
 	double getInitFov() const {return initFov;}
 	//! Set the initial Field Of View in degree.
-	void setInitFov(double fov) {initFov=fov;}
+	void setInitFov(double fov);
 
 	//! Return the inital viewing direction in altazimuthal coordinates
-	const Vec3d getInitViewingDirection() {return initViewPos;}
+	const Vec3d getInitViewingDirection() const {return initViewPos;}
 	//! Sets the initial direction of view to the current altitude and azimuth.
 	//! Note: Updates the configuration file.
 	void setInitViewDirectionToCurrent();
@@ -482,5 +485,5 @@ private:
 
 };
 
-#endif // _STELMOVEMENTMGR_HPP_
+#endif // STELMOVEMENTMGR_HPP
 
