@@ -69,6 +69,7 @@ void MilkyWay::init()
 	tex = StelApp::getInstance().getTextureManager().createTexture(StelFileMgr::getInstallationDir()+"/textures/milkyway.png");
 	setFlagShow(conf->value("astro/flag_milky_way").toBool());
 	setIntensity(conf->value("astro/milky_way_intensity",1.f).toFloat());
+	setProperty("saturation", conf->value("astro/milky_way_saturation", 1.f).toFloat());
 
 	// A new texture was provided by Fabien. Better resolution, but in equatorial coordinates. I had to enhance it a bit, and shift it by 90 degrees.
 	vertexArray = new StelVertexArray(StelPainter::computeSphereNoLight(1.f,1.f,45,15,1, true)); // GZ orig: slices=stacks=20.
@@ -194,6 +195,7 @@ void MilkyWay::draw(StelCore* core)
 	sPainter.setCullFace(true);
 	sPainter.setBlending(true, GL_ONE, GL_ONE); // allow colored sky background
 	tex->bind();
+	sPainter.setSaturation(saturation);
 	sPainter.drawStelVertexArray(*vertexArray);
 	sPainter.setCullFace(false);
 }
