@@ -30,6 +30,7 @@
 #include "StelCore.hpp"
 #include "StelPainter.hpp"
 #include "SolarSystem.hpp"
+#include "RefractionExtinction.hpp"
 
 #include <QTextStream>
 #include <QFile>
@@ -126,12 +127,14 @@ Nebula::Nebula()
 	, UGC_nb(0)
 	, Arp_nb(0)
 	, VV_nb(0)	
+	, Abell_nb(0)
 	, Ced_nb("")
 	, PK_nb("")
 	, PNG_nb("")
 	, SNRG_nb("")
 	, ACO_nb("")
 	, HCG_nb("")
+	, ESO_nb("")
 	, withoutID(false)
 	, nameI18("")
 	, mTypeString()
@@ -155,6 +158,32 @@ Nebula::~Nebula()
 {
 }
 
+QString Nebula::getMagnitudeInfoString(const StelCore *core, const InfoStringGroup& flags, const double alt_app, const int decimals) const
+{
+	QString res;
+	if (vMag < 50.f && flags&Magnitude)
+	{
+		QString emag = "";
+		QString tmag = q_("Magnitude");
+		if (nType == NebDn)
+			tmag = q_("Opacity");
+
+		if (nType != NebDn && core->getSkyDrawer()->getFlagHasAtmosphere() && (alt_app>-2.0*M_PI/180.0)) // Don't show extincted magnitude much below horizon where model is meaningless.
+		{
+			const Extinction &extinction=core->getSkyDrawer()->getExtinction();
+			float airmass=extinction.airmass(alt_app, true);
+
+			emag = QString(" (%1 <b>%2</b> %3 <b>%4</b> %5)").arg(q_("reduced to"), QString::number(getVMagnitudeWithExtinction(core), 'f', decimals), q_("by"), QString::number(airmass, 'f', 2), q_("Airmasses"));
+		}
+		res = QString("%1: <b>%2</b>%3<br />").arg(tmag, QString::number(getVMagnitude(core), 'f', decimals), emag);
+	}
+	if (bMag < 50.f && vMag > 50.f && flags&Magnitude)
+		res.append(QString("%1: <b>%2</b> (%3: B)<br />").arg(q_("Magnitude"), QString::number(bMag, 'f', decimals), q_("Photometric system")));
+	// TODO: Extinction for B magnitude? Or show B magnitude in addition to valid V magnitude?
+
+	return res;
+}
+
 QString Nebula::getInfoString(const StelCore *core, const InfoStringGroup& flags) const
 {
 	QString str;
@@ -222,6 +251,10 @@ QString Nebula::getInfoString(const StelCore *core, const InfoStringGroup& flags
 			catIds << QString("ACO %1").arg(ACO_nb);
 		if (!HCG_nb.isEmpty())
 			catIds << QString("HCG %1").arg(HCG_nb);
+		if (Abell_nb > 0)
+			catIds << QString("Abell %1").arg(Abell_nb);
+		if (!ESO_nb.isEmpty())
+			catIds << QString("ESO %1").arg(ESO_nb);
 
 		if (!nameI18.isEmpty() && !catIds.isEmpty() && flags&Name)
 			oss << "<br>";
@@ -241,20 +274,8 @@ QString Nebula::getInfoString(const StelCore *core, const InfoStringGroup& flags
 			oss << QString("%1: <b>%2</b> (%3)").arg(q_("Type"), getTypeString(), mt) << "<br>";
 	}
 
-	if (vMag < 50.f && flags&Magnitude)
-	{
-		QString emag = "";
-		QString tmag = q_("Magnitude");
-		if (nType == NebDn)
-			tmag = q_("Opacity");
+	oss << getMagnitudeInfoString(core, flags, alt_app, 2);
 
-		if (nType != NebDn && core->getSkyDrawer()->getFlagHasAtmosphere() && (alt_app>-3.0*M_PI/180.0)) // Don't show extincted magnitude much below horizon where model is meaningless.
-			emag = QString(" (%1: <b>%2</b>)").arg(q_("extincted to"), QString::number(getVMagnitudeWithExtinction(core), 'f', 2));
-
-		oss << QString("%1: <b>%2</b>%3").arg(tmag, QString::number(getVMagnitude(core), 'f', 2), emag) << "<br />";
-	}
-	if (bMag < 50.f && vMag > 50.f && flags&Magnitude)
-		oss << QString("%1: <b>%2</b> (%3: B)").arg(q_("Magnitude"), QString::number(bMag, 'f', 2), q_("Photometric system")) << "<br />";
 
 	if (flags&Extra)
 	{
@@ -283,7 +304,7 @@ QString Nebula::getInfoString(const StelCore *core, const InfoStringGroup& flags
 
 		if (getSurfaceBrightness(core)<99)
 		{
-			if (core->getSkyDrawer()->getFlagHasAtmosphere() && (alt_app>-3.0*M_PI/180.0) && getSurfaceBrightnessWithExtinction(core)<99) // Don't show extincted surface brightness much below horizon where model is meaningless.
+			if (core->getSkyDrawer()->getFlagHasAtmosphere() && (alt_app>-2.0*M_PI/180.0) && getSurfaceBrightnessWithExtinction(core)<99) // Don't show extincted surface brightness much below horizon where model is meaningless.
 			{
 				oss << QString("%1: <b>%2</b> %5 (%3: <b>%4</b> %5)").arg(sb, QString::number(getSurfaceBrightness(core, flagUseArcsecSurfaceBrightness), 'f', 2),
 											  ae, QString::number(getSurfaceBrightnessWithExtinction(core, flagUseArcsecSurfaceBrightness), 'f', 2), mu) << "<br />";
@@ -984,6 +1005,10 @@ QString Nebula::getDSODesignation() const
 		str = QString("ACO %1").arg(ACO_nb);
 	else if (catalogFilters&CatHCG && !HCG_nb.isEmpty())
 		str = QString("HCG %1").arg(HCG_nb);
+	else if (catalogFilters&CatAbell && Abell_nb > 0)
+		str = QString("Abell %1").arg(Abell_nb);
+	else if (catalogFilters&CatESO && !ESO_nb.isEmpty())
+		str = QString("ESO %1").arg(ESO_nb);
 
 	return str;
 }
@@ -997,10 +1022,10 @@ void Nebula::readDSO(QDataStream &in)
 		>> orientationAngle >> redshift >> redshiftErr >> parallax >> parallaxErr >> oDistance >> oDistanceErr
 		>> NGC_nb >> IC_nb >> M_nb >> C_nb >> B_nb >> Sh2_nb >> VdB_nb >> RCW_nb >> LDN_nb >> LBN_nb >> Cr_nb
 		>> Mel_nb >> PGC_nb >> UGC_nb >> Ced_nb >> Arp_nb >> VV_nb >> PK_nb >> PNG_nb >> SNRG_nb >> ACO_nb
-		>> HCG_nb;
+		>> HCG_nb >> Abell_nb >> ESO_nb;
 
-	int f = NGC_nb + IC_nb + M_nb + C_nb + B_nb + Sh2_nb + VdB_nb + RCW_nb + LDN_nb + LBN_nb + Cr_nb + Mel_nb + PGC_nb + UGC_nb + Arp_nb + VV_nb;
-	if (f==0 && Ced_nb.isEmpty() && PK_nb.isEmpty() && PNG_nb.isEmpty() && SNRG_nb.isEmpty() && ACO_nb.isEmpty() && HCG_nb.isEmpty())
+	int f = NGC_nb + IC_nb + M_nb + C_nb + B_nb + Sh2_nb + VdB_nb + RCW_nb + LDN_nb + LBN_nb + Cr_nb + Mel_nb + PGC_nb + UGC_nb + Arp_nb + VV_nb + Abell_nb;
+	if (f==0 && Ced_nb.isEmpty() && PK_nb.isEmpty() && PNG_nb.isEmpty() && SNRG_nb.isEmpty() && ACO_nb.isEmpty() && HCG_nb.isEmpty() && ESO_nb.isEmpty())
 		withoutID = true;
 
 	StelUtils::spheToRect(ra,dec,XYZ);
@@ -1149,6 +1174,10 @@ bool Nebula::objectInDisplayedCatalog() const
 		r = true;
 	else if ((catalogFilters&CatHCG) && (!HCG_nb.isEmpty()))
 		r = true;
+	else if ((catalogFilters&CatAbell) && (Abell_nb>0))
+		r = true;
+	else if ((catalogFilters&CatESO) && (!ESO_nb.isEmpty()))
+		r = true;
 
 	// Special case: objects without ID from current catalogs
 	if (withoutID)
