@@ -38,7 +38,8 @@ NomenclatureMgr::NomenclatureMgr()
 {
 	setObjectName("NomenclatureMgr");
 	conf = StelApp::getInstance().getSettings();
-	font.setPixelSize(StelApp::getInstance().getBaseFontSize());
+	font.setPixelSize(StelApp::getInstance().getScreenFontSize());
+	connect(&StelApp::getInstance(), SIGNAL(screenFontSizeChanged(int)), this, SLOT(setFontSize(int)));
 	ssystem = GETSTELMODULE(SolarSystem);
 }
 
@@ -137,6 +138,7 @@ void NomenclatureMgr::loadNomenclature()
 		QString name, ntypecode, planet = "", planetName = "", context = "";
 		NomenclatureItem::NomenclatureItemType ntype;
 		float latitude, longitude, size;
+		QStringList faultPlanets;
 
 		while (!planetSurfNamesFile.atEnd())
 		{
@@ -153,7 +155,7 @@ void NomenclatureMgr::loadNomenclature()
 			else
 			{
 				// Read the planet name
-				planet		= recRx.capturedTexts().at(1).trimmed();
+				planet	= recRx.capturedTexts().at(1).trimmed();
 				// Read the ID of feature
 				featureId	= recRx.capturedTexts().at(2).toInt();
 				// Read the name of feature and context
@@ -359,7 +361,6 @@ void NomenclatureMgr::loadNomenclature()
 					planetName = planet;					
 				}
 
-
 				if (!p.isNull())
 				{
 					NomenclatureItemP nom = NomenclatureItemP(new NomenclatureItem(p, featureId, name, context, ntype, latitude, longitude, size));
@@ -367,13 +368,21 @@ void NomenclatureMgr::loadNomenclature()
 						nomenclatureItems.insert(p, nom);
 
 					readOk++;
-				}				
+				}
+				else
+					faultPlanets << planet;
+
 			}
 		}
 
 		planetSurfNamesFile.close();
 		qDebug() << "Loaded" << readOk << "/" << totalRecords << "items of planetary surface nomenclature";
 
+		faultPlanets.removeDuplicates();
+		int err = faultPlanets.size();
+		if (err>0)
+			qDebug() << "WARNING - The next planets to assign nomenclature items is not found:" << faultPlanets.join(", ");
+
 	}
 }
 
