@@ -87,11 +87,12 @@ SolarSystem::SolarSystem()
 	, allTrails(Q_NULLPTR)
 	, conf(StelApp::getInstance().getSettings())
 {
-	planetNameFont.setPixelSize(StelApp::getInstance().getBaseFontSize());
+	planetNameFont.setPixelSize(StelApp::getInstance().getScreenFontSize());
+	connect(&StelApp::getInstance(), SIGNAL(screenFontSizeChanged(int)), this, SLOT(setFontSize(int)));
 	setObjectName("SolarSystem");
 }
 
-void SolarSystem::setFontSize(float newFontSize)
+void SolarSystem::setFontSize(int newFontSize)
 {
 	planetNameFont.setPixelSize(newFontSize);
 }
@@ -203,6 +204,7 @@ void SolarSystem::init()
 	setOortCloudObjectsOrbitsColor(StelUtils::strToVec3f(conf->value("color/oco_orbits_color", "0.7,0.5,0.5").toString()));
 	setCometsOrbitsColor(StelUtils::strToVec3f(conf->value("color/comet_orbits_color", "0.7,0.8,0.8").toString()));
 	setSednoidsOrbitsColor(StelUtils::strToVec3f(conf->value("color/sednoid_orbits_color", "0.7,0.5,0.5").toString()));
+	setInterstellarOrbitsColor(StelUtils::strToVec3f(conf->value("color/interstellar_orbits_color", "1.0,0.6,1.0").toString()));
 	setMercuryOrbitColor(StelUtils::strToVec3f(conf->value("color/mercury_orbit_color", "0.5,0.5,0.5").toString()));
 	setVenusOrbitColor(StelUtils::strToVec3f(conf->value("color/venus_orbit_color", "0.9,0.9,0.7").toString()));
 	setEarthOrbitColor(StelUtils::strToVec3f(conf->value("color/earth_orbit_color", "0.0,0.0,1.0").toString()));
@@ -240,6 +242,8 @@ void SolarSystem::init()
 	//there is a small discrepancy in the GUI: "Show planet markers" actually means show planet hints
 	addAction("actionShow_Planets_Hints", displayGroup, N_("Planet markers"), "flagHints", "Ctrl+P");
 	addAction("actionShow_Planets_Pointers", displayGroup, N_("Planet selection marker"), "flagPointer", "Ctrl+Shift+P");
+	addAction("actionShow_Planets_EnlargeMoon", displayGroup, N_("Enlarge Moon"), "flagMoonScale");
+	addAction("actionShow_Planets_EnlargeMinor", displayGroup, N_("Enlarge minor bodies"), "flagMinorBodyScale");
 	addAction("actionShow_Skyculture_NativePlanetNames", displayGroup, N_("Native planet names (from starlore)"), "flagNativePlanetNames", "Ctrl+Shift+N");
 
 	connect(StelApp::getInstance().getModule("HipsMgr"), SIGNAL(gotNewSurvey(HipsSurveyP)),
@@ -959,7 +963,7 @@ bool SolarSystem::loadPlanets(const QString& filePath)
 		// New class objects, named "plutino", "cubewano", "dwarf planet", "SDO", "OCO", has properties
 		// similar to asteroids and we should calculate their positions like for asteroids. Dwarf planets
 		// have one exception: Pluto - we should use special function for calculation of orbit of Pluto.
-		if ((type == "asteroid" || type == "dwarf planet" || type == "cubewano" || type == "plutino" || type == "scattered disc object" || type == "Oort cloud object") && !englishName.contains("Pluto"))
+		if ((type == "asteroid" || type == "dwarf planet" || type == "cubewano" || type == "plutino" || type == "scattered disc object" || type == "Oort cloud object" || type == "interstellar object") && !englishName.contains("Pluto"))
 		{
 			minorBodies << englishName;
 
@@ -1705,7 +1709,7 @@ void SolarSystem::update(double deltaTime)
 }
 
 // is a lunar eclipse close at hand?
-bool SolarSystem::nearLunarEclipse()
+bool SolarSystem::nearLunarEclipse() const
 {
 	// TODO: could replace with simpler test
 
@@ -1947,7 +1951,11 @@ bool SolarSystem::getFlagPlanetsOrbitsOnly() const
 // Set/Get planets names color
 void SolarSystem::setLabelsColor(const Vec3f& c)
 {
-	Planet::setLabelColor(c);
+	if (c!=Planet::getLabelColor())
+	{
+		Planet::setLabelColor(c);
+		emit labelsColorChanged(c);
+	}
 }
 
 const Vec3f& SolarSystem::getLabelsColor(void) const
@@ -1958,7 +1966,11 @@ const Vec3f& SolarSystem::getLabelsColor(void) const
 // Set/Get orbits lines color
 void SolarSystem::setOrbitsColor(const Vec3f& c)
 {
-	Planet::setOrbitColor(c);
+	if (c!=Planet::getOrbitColor())
+	{
+		Planet::setOrbitColor(c);
+		emit orbitsColorChanged(c);
+	}
 }
 
 Vec3f SolarSystem::getOrbitsColor(void) const
@@ -1968,7 +1980,11 @@ Vec3f SolarSystem::getOrbitsColor(void) const
 
 void SolarSystem::setMajorPlanetsOrbitsColor(const Vec3f &c)
 {
-	Planet::setMajorPlanetOrbitColor(c);
+	if (c!=Planet::getMajorPlanetOrbitColor())
+	{
+		Planet::setMajorPlanetOrbitColor(c);
+		emit majorPlanetsOrbitsColorChanged(c);
+	}
 }
 
 Vec3f SolarSystem::getMajorPlanetsOrbitsColor(void) const
@@ -1978,7 +1994,11 @@ Vec3f SolarSystem::getMajorPlanetsOrbitsColor(void) const
 
 void SolarSystem::setMinorPlanetsOrbitsColor(const Vec3f &c)
 {
-	Planet::setMinorPlanetOrbitColor(c);
+	if (c!=Planet::getMinorPlanetOrbitColor())
+	{
+		Planet::setMinorPlanetOrbitColor(c);
+		emit minorPlanetsOrbitsColorChanged(c);
+	}
 }
 
 Vec3f SolarSystem::getMinorPlanetsOrbitsColor(void) const
@@ -1988,7 +2008,11 @@ Vec3f SolarSystem::getMinorPlanetsOrbitsColor(void) const
 
 void SolarSystem::setDwarfPlanetsOrbitsColor(const Vec3f &c)
 {
-	Planet::setDwarfPlanetOrbitColor(c);
+	if (c!=Planet::getDwarfPlanetOrbitColor())
+	{
+		Planet::setDwarfPlanetOrbitColor(c);
+		emit dwarfPlanetsOrbitsColorChanged(c);
+	}
 }
 
 Vec3f SolarSystem::getDwarfPlanetsOrbitsColor(void) const
@@ -1998,7 +2022,11 @@ Vec3f SolarSystem::getDwarfPlanetsOrbitsColor(void) const
 
 void SolarSystem::setMoonsOrbitsColor(const Vec3f &c)
 {
-	Planet::setMoonOrbitColor(c);
+	if (c!=Planet::getMoonOrbitColor())
+	{
+		Planet::setMoonOrbitColor(c);
+		emit moonsOrbitsColorChanged(c);
+	}
 }
 
 Vec3f SolarSystem::getMoonsOrbitsColor(void) const
@@ -2008,7 +2036,11 @@ Vec3f SolarSystem::getMoonsOrbitsColor(void) const
 
 void SolarSystem::setCubewanosOrbitsColor(const Vec3f &c)
 {
-	Planet::setCubewanoOrbitColor(c);
+	if (c!=Planet::getCubewanoOrbitColor())
+	{
+		Planet::setCubewanoOrbitColor(c);
+		emit cubewanosOrbitsColorChanged(c);
+	}
 }
 
 Vec3f SolarSystem::getCubewanosOrbitsColor(void) const
@@ -2018,7 +2050,11 @@ Vec3f SolarSystem::getCubewanosOrbitsColor(void) const
 
 void SolarSystem::setPlutinosOrbitsColor(const Vec3f &c)
 {
-	Planet::setPlutinoOrbitColor(c);
+	if (c!=Planet::getPlutinoOrbitColor())
+	{
+		Planet::setPlutinoOrbitColor(c);
+		emit plutinosOrbitsColorChanged(c);
+	}
 }
 
 Vec3f SolarSystem::getPlutinosOrbitsColor(void) const
@@ -2028,7 +2064,11 @@ Vec3f SolarSystem::getPlutinosOrbitsColor(void) const
 
 void SolarSystem::setScatteredDiskObjectsOrbitsColor(const Vec3f &c)
 {
-	Planet::setScatteredDiscObjectOrbitColor(c);
+	if (c!=Planet::getScatteredDiscObjectOrbitColor())
+	{
+		Planet::setScatteredDiscObjectOrbitColor(c);
+		emit scatteredDiskObjectsOrbitsColorChanged(c);
+	}
 }
 
 Vec3f SolarSystem::getScatteredDiskObjectsOrbitsColor(void) const
@@ -2038,7 +2078,11 @@ Vec3f SolarSystem::getScatteredDiskObjectsOrbitsColor(void) const
 
 void SolarSystem::setOortCloudObjectsOrbitsColor(const Vec3f &c)
 {
-	Planet::setOortCloudObjectOrbitColor(c);
+	if (c!=Planet::getOortCloudObjectOrbitColor())
+	{
+		Planet::setOortCloudObjectOrbitColor(c);
+		emit oortCloudObjectsOrbitsColorChanged(c);
+	}
 }
 
 Vec3f SolarSystem::getOortCloudObjectsOrbitsColor(void) const
@@ -2048,7 +2092,11 @@ Vec3f SolarSystem::getOortCloudObjectsOrbitsColor(void) const
 
 void SolarSystem::setCometsOrbitsColor(const Vec3f& c)
 {
-	Planet::setCometOrbitColor(c);
+	if (c!=Planet::getCometOrbitColor())
+	{
+		Planet::setCometOrbitColor(c);
+		emit cometsOrbitsColorChanged(c);
+	}
 }
 
 Vec3f SolarSystem::getCometsOrbitsColor(void) const
@@ -2058,7 +2106,11 @@ Vec3f SolarSystem::getCometsOrbitsColor(void) const
 
 void SolarSystem::setSednoidsOrbitsColor(const Vec3f& c)
 {
-	Planet::setSednoidOrbitColor(c);
+	if (c!=Planet::getSednoidOrbitColor())
+	{
+		Planet::setSednoidOrbitColor(c);
+		emit sednoidsOrbitsColorChanged(c);
+	}
 }
 
 Vec3f SolarSystem::getSednoidsOrbitsColor(void) const
@@ -2066,9 +2118,27 @@ Vec3f SolarSystem::getSednoidsOrbitsColor(void) const
 	return Planet::getSednoidOrbitColor();
 }
 
+void SolarSystem::setInterstellarOrbitsColor(const Vec3f& c)
+{
+	if (c!=Planet::getInterstellarOrbitColor())
+	{
+		Planet::setInterstellarOrbitColor(c);
+		emit interstellarOrbitsColorChanged(c);
+	}
+}
+
+Vec3f SolarSystem::getInterstellarOrbitsColor(void) const
+{
+	return Planet::getInterstellarOrbitColor();
+}
+
 void SolarSystem::setMercuryOrbitColor(const Vec3f &c)
 {
-	Planet::setMercuryOrbitColor(c);
+	if (c!=Planet::getMercuryOrbitColor())
+	{
+		Planet::setMercuryOrbitColor(c);
+		emit mercuryOrbitColorChanged(c);
+	}
 }
 
 Vec3f SolarSystem::getMercuryOrbitColor(void) const
@@ -2078,7 +2148,11 @@ Vec3f SolarSystem::getMercuryOrbitColor(void) const
 
 void SolarSystem::setVenusOrbitColor(const Vec3f &c)
 {
-	Planet::setVenusOrbitColor(c);
+	if (c!=Planet::getVenusOrbitColor())
+	{
+		Planet::setVenusOrbitColor(c);
+		emit venusOrbitColorChanged(c);
+	}
 }
 
 Vec3f SolarSystem::getVenusOrbitColor(void) const
@@ -2088,7 +2162,11 @@ Vec3f SolarSystem::getVenusOrbitColor(void) const
 
 void SolarSystem::setEarthOrbitColor(const Vec3f &c)
 {
-	Planet::setEarthOrbitColor(c);
+	if (c!=Planet::getEarthOrbitColor())
+	{
+		Planet::setEarthOrbitColor(c);
+		emit earthOrbitColorChanged(c);
+	}
 }
 
 Vec3f SolarSystem::getEarthOrbitColor(void) const
@@ -2098,7 +2176,11 @@ Vec3f SolarSystem::getEarthOrbitColor(void) const
 
 void SolarSystem::setMarsOrbitColor(const Vec3f &c)
 {
-	Planet::setMarsOrbitColor(c);
+	if (c!=Planet::getMarsOrbitColor())
+	{
+		Planet::setMarsOrbitColor(c);
+		emit marsOrbitColorChanged(c);
+	}
 }
 
 Vec3f SolarSystem::getMarsOrbitColor(void) const
@@ -2108,7 +2190,11 @@ Vec3f SolarSystem::getMarsOrbitColor(void) const
 
 void SolarSystem::setJupiterOrbitColor(const Vec3f &c)
 {
-	Planet::setJupiterOrbitColor(c);
+	if (c!=Planet::getJupiterOrbitColor())
+	{
+		Planet::setJupiterOrbitColor(c);
+		emit jupiterOrbitColorChanged(c);
+	}
 }
 
 Vec3f SolarSystem::getJupiterOrbitColor(void) const
@@ -2118,7 +2204,11 @@ Vec3f SolarSystem::getJupiterOrbitColor(void) const
 
 void SolarSystem::setSaturnOrbitColor(const Vec3f &c)
 {
-	Planet::setSaturnOrbitColor(c);
+	if (c!=Planet::getSaturnOrbitColor())
+	{
+		Planet::setSaturnOrbitColor(c);
+		emit saturnOrbitColorChanged(c);
+	}
 }
 
 Vec3f SolarSystem::getSaturnOrbitColor(void) const
@@ -2128,7 +2218,11 @@ Vec3f SolarSystem::getSaturnOrbitColor(void) const
 
 void SolarSystem::setUranusOrbitColor(const Vec3f &c)
 {
-	Planet::setUranusOrbitColor(c);
+	if (c!=Planet::getUranusOrbitColor())
+	{
+		Planet::setUranusOrbitColor(c);
+		emit uranusOrbitColorChanged(c);
+	}
 }
 
 Vec3f SolarSystem::getUranusOrbitColor(void) const
@@ -2138,7 +2232,11 @@ Vec3f SolarSystem::getUranusOrbitColor(void) const
 
 void SolarSystem::setNeptuneOrbitColor(const Vec3f &c)
 {
-	Planet::setNeptuneOrbitColor(c);
+	if (c!=Planet::getNeptuneOrbitColor())
+	{
+		Planet::setNeptuneOrbitColor(c);
+		emit neptuneOrbitColorChanged(c);
+	}
 }
 
 Vec3f SolarSystem::getNeptuneOrbitColor(void) const
@@ -2338,6 +2436,7 @@ void SolarSystem::reloadPlanets()
 void SolarSystem::setApparentMagnitudeAlgorithmOnEarth(QString algorithm)
 {
 	Planet::setApparentMagnitudeAlgorithm(algorithm);
+	emit apparentMagnitudeAlgorithmOnEarthChanged(algorithm);
 }
 
 // Get the algorithm used for computation of apparent magnitudes for planets in case  observer on the Earth
@@ -2359,7 +2458,7 @@ void SolarSystem::setFlagCustomGrsSettings(bool b)
 	emit flagCustomGrsSettingsChanged(b);
 }
 
-bool SolarSystem::getFlagCustomGrsSettings()
+bool SolarSystem::getFlagCustomGrsSettings() const
 {
 	return Planet::flagCustomGrsSettings;
 }
@@ -2372,7 +2471,7 @@ void SolarSystem::setCustomGrsLongitude(int longitude)
 	emit customGrsLongitudeChanged(longitude);
 }
 
-int SolarSystem::getCustomGrsLongitude()
+int SolarSystem::getCustomGrsLongitude() const
 {
 	return Planet::customGrsLongitude;
 }
@@ -2385,7 +2484,7 @@ void SolarSystem::setCustomGrsDrift(double drift)
 	emit customGrsDriftChanged(drift);
 }
 
-double SolarSystem::getCustomGrsDrift()
+double SolarSystem::getCustomGrsDrift() const
 {
 	return Planet::customGrsDrift;
 }
