@@ -18,8 +18,8 @@
  * Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA  02110-1335, USA.
  */
 
-#ifndef _SOLARSYSTEM_HPP_
-#define _SOLARSYSTEM_HPP_
+#ifndef SOLARSYSTEM_HPP
+#define SOLARSYSTEM_HPP
 //sun is already defined in Sun C/Solaris
 #if defined(sun)
 #undef sun
@@ -244,6 +244,11 @@ class SolarSystem : public StelObjectModule
 		   WRITE setSednoidsOrbitsColor
 		   NOTIFY sednoidsOrbitsColorChanged
 		   )
+	Q_PROPERTY(Vec3f interstellarOrbitsColor
+		   READ getInterstellarOrbitsColor
+		   WRITE setInterstellarOrbitsColor
+		   NOTIFY interstellarOrbitsColorChanged
+		   )
 	Q_PROPERTY(Vec3f mercuryOrbitColor
 		   READ getMercuryOrbitColor
 		   WRITE setMercuryOrbitColor
@@ -292,6 +297,11 @@ class SolarSystem : public StelObjectModule
 		   NOTIFY orbitColorStyleChanged
 		   )
 
+	Q_PROPERTY(QString apparentMagnitudeAlgorithmOnEarth
+		   READ getApparentMagnitudeAlgorithmOnEarth
+		   WRITE setApparentMagnitudeAlgorithmOnEarth
+		   NOTIFY apparentMagnitudeAlgorithmOnEarthChanged)
+
 public:
 	SolarSystem();
 	virtual ~SolarSystem();
@@ -412,7 +422,7 @@ public slots:
 
 	//! Set planet names font size.
 	//! @return font size
-	void setFontSize(float newFontSize);
+	void setFontSize(int newFontSize);
 
 	//! Set the color used to draw planet labels.
 	//! @param c The color of the planet labels (R,G,B)
@@ -546,6 +556,17 @@ public slots:
 	//! @return current color
 	Vec3f getSednoidsOrbitsColor(void) const;
 
+	//! Set the color used to draw interstellar orbit (hyperbolic trajectory) lines.
+	//! @param c The color of the interstellar orbit lines (R,G,B)
+	//! @code
+	//! // example of usage in scripts
+	//! SolarSystem.setInterstellarOrbitsColor(Vec3f(1.0,0.0,0.0));
+	//! @endcode
+	void setInterstellarOrbitsColor(const Vec3f& c);
+	//! Get the current color used to draw interstellar orbit lines.
+	//! @return current color
+	Vec3f getInterstellarOrbitsColor(void) const;
+
 	//! Set the color used to draw Mercury orbit line.
 	//! @param c The color of Mercury orbit line (R,G,B)
 	//! @code
@@ -760,20 +781,20 @@ public slots:
 	//! Set flag which determines if custom settings is using for Great Red Spot on Jupiter
 	void setFlagCustomGrsSettings(bool b);
 	//! Get the current value of the flag which determines if custom settings for Great Red Spot on Jupiter is used or not.
-	bool getFlagCustomGrsSettings();
+	bool getFlagCustomGrsSettings() const;
 
 	//! Set longitude of Great Red Spot (System II is used)
 	//! @param longitude (degrees)
 	void setCustomGrsLongitude(int longitude);
 	//! Get longitude of Great Red Spot (System II is used)
 	//! @return a longitude (degrees)
-	int getCustomGrsLongitude();
+	int getCustomGrsLongitude() const;
 
 	//! Set speed of annual drift for Great Red Spot (System II is used)
 	//! @param annual drift (degrees)
 	void setCustomGrsDrift(double drift);
 	//! Get speed of annual drift for Great Red Spot (System II is used)
-	double getCustomGrsDrift();
+	double getCustomGrsDrift() const;
 
 	//! Set initial JD for calculation of position of Great Red Spot
 	//! @param JD
@@ -835,6 +856,7 @@ signals:
 	void oortCloudObjectsOrbitsColorChanged(const Vec3f & color) const;
 	void cometsOrbitsColorChanged(const Vec3f & color) const;
 	void sednoidsOrbitsColorChanged(const Vec3f & color) const;
+	void interstellarOrbitsColorChanged(const Vec3f & color) const;
 	void mercuryOrbitColorChanged(const Vec3f & color) const;
 	void venusOrbitColorChanged(const Vec3f & color) const;
 	void earthOrbitColorChanged(const Vec3f & color) const;
@@ -845,6 +867,7 @@ signals:
 	void neptuneOrbitColorChanged(const Vec3f & color) const;
 
 	void orbitColorStyleChanged(QString style) const;
+	void apparentMagnitudeAlgorithmOnEarthChanged(QString algorithm) const;
 
 	void solarSystemDataReloaded();
 
@@ -868,7 +891,7 @@ public:
 	PlanetP getMoon() const {return moon;}
 
 	//! Determine if a lunar eclipse is close at hand?
-	bool nearLunarEclipse();
+	bool nearLunarEclipse() const;
 
 	//! Get the list of all the planet english names
 	QStringList getAllPlanetEnglishNames() const;
@@ -960,7 +983,8 @@ private:
 	//! @param bV value of B-V color index
 	unsigned char BvToColorIndex(float bV);
 
-	//! Set flag who enable display a permanent orbits for objects or not
+	//! Set flag which enables display of permanent orbits for objects
+	// TODO: DOCUMENT what this really does, under which circumstances etc.
 	void setFlagPermanentOrbits(bool b);
 
 	//! Used to count how many planets actually need shadow information
@@ -1040,4 +1064,4 @@ private:
 };
 
 
-#endif // _SOLARSYSTEM_HPP_
+#endif // SOLARSYSTEM_HPP
