@@ -18,8 +18,8 @@
  * Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA  02110-1335, USA.
  */
 
-#ifndef _ANGLESPINBOX_HPP_
-#define _ANGLESPINBOX_HPP_
+#ifndef ANGLESPINBOX_HPP
+#define ANGLESPINBOX_HPP
 
 #include <QAbstractSpinBox>
 #include <QString>
@@ -69,10 +69,10 @@ public:
 
 	//! Get the angle held in the AngleSpinBox
 	//! @return the angle in radians
-	double valueRadians();
+	double valueRadians() const;
 	//! Get the angle held in the AngleSpinBox
 	//! @return the angle in degrees
-	double valueDegrees();
+	double valueDegrees() const;
 
 	//! Set the number of decimal places to express float values to (e.g. seconds in DMSLetters format).
 	//! @param places the number of decimal places to use.
@@ -80,7 +80,7 @@ public:
 
 	//! Get the number of decimal places to express float values to (e.g. seconds in DMSLetters format).
 	//! @return the number of decimal places used.
-	int decimals() { return decimalPlaces; }
+	int decimals() const { return decimalPlaces; }
 
 	//! Set the display format.
 	//! @param format the new format to use.
@@ -88,7 +88,7 @@ public:
 
 	//! Get the current display format.
 	//! @return the current DisplayFormat.
-	DisplayFormat displayFormat() { return angleSpinBoxFormat; }
+	DisplayFormat displayFormat() const { return angleSpinBoxFormat; }
 
 	//! Set the prefix type.
 	//! @param prefix the new prefix type to use.
@@ -96,7 +96,7 @@ public:
 
 	//! Get the current display format.
 	//! @return the current DisplayFormat.
-	PrefixType prefixType() { return currentPrefixType; }
+	PrefixType prefixType() const { return currentPrefixType; }
 
 	//! Set the minimum value.
 	//! @param min the new minimum value
@@ -105,7 +105,7 @@ public:
 	//! Get the minimum value.
 	//! @return the current minimum value
 	//! @param isDegrees true if the minimum value is required in degrees, else min is returned as radians.
-	double getMinimum(const bool isDegrees) { return minRad * (isDegrees ? 180.0/M_PI : 1.0); }
+	double getMinimum(const bool isDegrees) const { return minRad * (isDegrees ? 180.0/M_PI : 1.0); }
 
 	//! Set the maximum value.
 	//! @param max the new maximum value
@@ -114,7 +114,7 @@ public:
 	//! Get the maximum value.
 	//! @return the current maximum value
 	//! @param isDegrees true if the maximum value is required in degrees, else max is returned as radians.
-	double getMaximum(const bool isDegrees) { return maxRad * (isDegrees ? 180.0/M_PI : 1.0); }
+	double getMaximum(const bool isDegrees) const { return maxRad * (isDegrees ? 180.0/M_PI : 1.0); }
 
 	
 public slots:
@@ -181,4 +181,4 @@ private:
 	double maxRad;
 };
 
-#endif // _ANGLESPINBOX_HPP_
+#endif // ANGLESPINBOX_HPP
