@@ -27,10 +27,12 @@
 #include "StelLocation.hpp"
 #include "StelLocationMgr.hpp"
 #include "CustomObjectMgr.hpp"
+#include "HighlightMgr.hpp"
 #include "StelFileMgr.hpp"
 #include "StelJsonParser.hpp"
 #include "AngleSpinBox.hpp"
 #include "NebulaMgr.hpp"
+#include "StarMgr.hpp"
 
 #include <QFileDialog>
 #include <QDir>
@@ -83,6 +85,9 @@ void BookmarksDialog::createDialogContent()
 	connect(ui->clearBookmarksButton, SIGNAL(clicked()), this, SLOT(clearBookmarksButtonPressed()));
 	connect(ui->bookmarksTreeView, SIGNAL(doubleClicked(QModelIndex)), this, SLOT(selectCurrentBookmark(QModelIndex)));
 
+	connect(ui->clearHighlightsButton, SIGNAL(clicked()), this, SLOT(clearHighlightsButtonPressed()));
+	connect(ui->highlightBookmarksButton, SIGNAL(clicked()), this, SLOT(highlightBookrmarksButtonPressed()));
+
 	connect(ui->importBookmarksButton, SIGNAL(clicked()), this, SLOT(importBookmarks()));
 	connect(ui->exportBookmarksButton, SIGNAL(clicked()), this, SLOT(exportBookmarks()));
 
@@ -153,19 +158,23 @@ void BookmarksDialog::addBookmarkButtonPressed()
 
 		QString raStr = "", decStr = "";
 		bool visibleFlag = false;
-		if (selected[0]->getType()=="CustomObject")
+		double fov = -1.0;
+
+		if (name.isEmpty() || selected[0]->getType()=="CustomObject")
 		{
-			if (name.isEmpty())
-			{
-				name = "Unnamed object";
-				nameI18n = q_("Unnamed object");
-			}
 			float ra, dec;
 			StelUtils::rectToSphe(&ra, &dec, selected[0]->getJ2000EquatorialPos(core));
-			raStr = StelUtils::radToHmsStr(ra, false);
-			decStr = StelUtils::radToDmsStr(dec, false);
+			raStr = StelUtils::radToHmsStr(ra, false).trimmed();
+			decStr = StelUtils::radToDmsStr(dec, false).trimmed();
 			if (name.contains("marker", Qt::CaseInsensitive))
 				visibleFlag = true;
+
+			if (name.isEmpty())
+			{
+				name = QString("%1, %2").arg(raStr, decStr);
+				nameI18n = q_("Unnamed star");
+				fov = GETSTELMODULE(StelMovementMgr)->getCurrentFov();
+			}
 		}
 
 		bool dateTimeFlag = ui->dateTimeCheckBox->isChecked();
@@ -209,6 +218,8 @@ void BookmarksDialog::addBookmarkButtonPressed()
 			bm.location = Location;
 		if (!visibleFlag)
 			bm.isVisibleMarker = visibleFlag;
+		if (fov > 0.0)
+			bm.fov = fov;
 
 		bookmarksCollection.insert(uuid, bm);
 
@@ -227,6 +238,7 @@ void BookmarksDialog::removeBookmarkButtonPressed()
 
 void BookmarksDialog::clearBookmarksButtonPressed()
 {
+	GETSTELMODULE(HighlightMgr)->cleanHighlightList();
 	bookmarksListModel->clear();
 	bookmarksCollection.clear();
 	setBookmarksHeaderNames();
@@ -239,6 +251,47 @@ void BookmarksDialog::goToBookmarkButtonPressed()
 	goToBookmark(bookmarksListModel->index(ui->bookmarksTreeView->currentIndex().row(), ColumnUUID).data().toString());
 }
 
+void BookmarksDialog::highlightBookrmarksButtonPressed()
+{
+	QList<Vec3d> highlights;
+	highlights.clear();
+
+	for (auto bm : bookmarksCollection)
+	{
+		QString name	= bm.name;
+		QString raStr	= bm.ra.trimmed();
+		QString decStr	= bm.dec.trimmed();
+
+		Vec3d pos;
+		bool status = false;
+		if (!raStr.isEmpty() && !decStr.isEmpty())
+		{
+			StelUtils::spheToRect(StelUtils::getDecAngle(raStr), StelUtils::getDecAngle(decStr), pos);
+			status = true;
+		}
+		else
+		{
+			status = objectMgr->findAndSelect(name);
+			const QList<StelObjectP>& selected = objectMgr->getSelectedObject();
+			if (!selected.isEmpty())
+				pos = selected[0]->getJ2000EquatorialPos(core);
+		}
+
+		if (status)
+			highlights.append(pos);
+
+		objectMgr->unSelect();
+	}
+
+	GETSTELMODULE(HighlightMgr)->fillHighlightList(highlights);
+}
+
+void BookmarksDialog::clearHighlightsButtonPressed()
+{
+	GETSTELMODULE(HighlightMgr)->cleanHighlightList();
+	objectMgr->unSelect();
+}
+
 void BookmarksDialog::selectCurrentBookmark(const QModelIndex &modelIdx)
 {
 	goToBookmark(modelIdx.sibling(modelIdx.row(), ColumnUUID).data().toString());
@@ -261,14 +314,57 @@ void BookmarksDialog::goToBookmark(QString uuid)
 
 		StelMovementMgr* mvmgr = GETSTELMODULE(StelMovementMgr);
 		objectMgr->unSelect();
+
 		bool status = objectMgr->findAndSelect(bm.name);
+		float amd = mvmgr->getAutoMoveDuration();
 		if (!bm.ra.isEmpty() && !bm.dec.isEmpty() && !status)
 		{
 			Vec3d pos;
 			StelUtils::spheToRect(StelUtils::getDecAngle(bm.ra.trimmed()), StelUtils::getDecAngle(bm.dec.trimmed()), pos);
-			// Add a custom object on the sky
-			GETSTELMODULE(CustomObjectMgr)->addCustomObject(bm.name, pos, bm.isVisibleMarker);
-			status = objectMgr->findAndSelect(bm.name);
+			if (bm.name.contains("marker", Qt::CaseInsensitive))
+			{
+				// Add a custom object on the sky
+				GETSTELMODULE(CustomObjectMgr)->addCustomObject(bm.name, pos, bm.isVisibleMarker);
+				status = objectMgr->findAndSelect(bm.name);
+			}
+			else
+			{
+				// The unnamed stars
+				StelObjectP sobj;
+				const StelProjectorP prj = core->getProjection(StelCore::FrameJ2000);
+				double fov = 5.0;
+				if (bm.fov > 0.0)
+					fov = bm.fov;
+
+				mvmgr->zoomTo(fov, 0.0);
+				mvmgr->moveToJ2000(pos, mvmgr->mountFrameToJ2000(Vec3d(0., 0., 1.)), 0.0);
+
+				QList<StelObjectP> candidates = GETSTELMODULE(StarMgr)->searchAround(pos, 0.5, core);
+				if (candidates.empty()) // The FOV is too big, let's reduce it
+				{
+					mvmgr->zoomTo(0.5*fov, 0.0);
+					candidates = GETSTELMODULE(StarMgr)->searchAround(pos, 0.5, core);
+				}
+
+				Vec3d winpos;
+				prj->project(pos, winpos);
+				float xpos = winpos[0];
+				float ypos = winpos[1];
+				float best_object_value = 1000.f;
+				for (const auto& obj : candidates)
+				{
+					prj->project(obj->getJ2000EquatorialPos(core), winpos);
+					float distance = std::sqrt((xpos-winpos[0])*(xpos-winpos[0]) + (ypos-winpos[1])*(ypos-winpos[1]));
+					if (distance < best_object_value)
+					{
+						best_object_value = distance;
+						sobj = obj;
+					}
+				}
+
+				if (sobj)
+					status = objectMgr->setSelectedObject(sobj);
+			}
 		}
 
 		if (status)
@@ -276,7 +372,7 @@ void BookmarksDialog::goToBookmark(QString uuid)
 			const QList<StelObjectP> newSelected = objectMgr->getSelectedObject();
 			if (!newSelected.empty())
 			{
-				mvmgr->moveToObject(newSelected[0], mvmgr->getAutoMoveDuration());
+				mvmgr->moveToObject(newSelected[0], amd);
 				mvmgr->setFlagTracking(true);
 			}
 		}
@@ -288,48 +384,61 @@ void BookmarksDialog::loadBookmarks()
 	QVariantMap map;
 	QFile jsonFile(bookmarksJsonPath);
 	if (!jsonFile.open(QIODevice::ReadOnly))
-		qWarning() << "Bookmarks: cannot open" << QDir::toNativeSeparators(bookmarksJsonPath);
+		qWarning() << "[Bookmarks] cannot open" << QDir::toNativeSeparators(bookmarksJsonPath);
 	else
 	{
-		map = StelJsonParser::parse(jsonFile.readAll()).toMap();
-		jsonFile.close();
-	}
-
-	bookmarksCollection.clear();
-	QVariantMap bookmarksMap = map.value("bookmarks").toMap();
-	int i = 0;
-	for (auto bookmarkKey : bookmarksMap.keys())
-	{
-		QVariantMap bookmarkData = bookmarksMap.value(bookmarkKey).toMap();
-		bookmark bm;
-
-		QString JDs = "";
-
-		bm.name = bookmarkData.value("name").toString();
-		QString nameI18n = bookmarkData.value("nameI18n").toString();
-		if (!nameI18n.isEmpty())
-			bm.nameI18n = nameI18n;
-		QString JD = bookmarkData.value("jd").toString();
-		if (!JD.isEmpty())
+		try
 		{
-			bm.jd = JD;
-			JDs = StelUtils::julianDayToISO8601String(JD.toDouble() + core->getUTCOffset(JD.toDouble())/24.).replace("T", " ");
+			map = StelJsonParser::parse(jsonFile.readAll()).toMap();
+			jsonFile.close();
+
+			bookmarksCollection.clear();
+			QVariantMap bookmarksMap = map.value("bookmarks").toMap();
+			int i = 0;
+			for (auto bookmarkKey : bookmarksMap.keys())
+			{
+				QVariantMap bookmarkData = bookmarksMap.value(bookmarkKey).toMap();
+				bookmark bm;
+
+				QString JDs = "";
+
+				bm.name = bookmarkData.value("name").toString();
+				QString nameI18n = bookmarkData.value("nameI18n").toString();
+				if (!nameI18n.isEmpty())
+					bm.nameI18n = nameI18n;
+				QString JD = bookmarkData.value("jd").toString();
+				if (!JD.isEmpty())
+				{
+					bm.jd = JD;
+					JDs = StelUtils::julianDayToISO8601String(JD.toDouble() + core->getUTCOffset(JD.toDouble())/24.).replace("T", " ");
+				}
+				QString Location = bookmarkData.value("location").toString();
+				if (!Location.isEmpty())
+					bm.location = Location;
+				QString RA = bookmarkData.value("ra").toString();
+				if (!RA.isEmpty())
+					bm.ra = RA;
+				QString Dec = bookmarkData.value("dec").toString();
+				if (!Dec.isEmpty())
+					bm.dec = Dec;
+
+				bm.isVisibleMarker = bookmarkData.value("isVisibleMarker", false).toBool();
+				double fov = bookmarkData.value("fov").toDouble();
+				if (fov > 0.0)
+					bm.fov = fov;
+
+				bookmarksCollection.insert(bookmarkKey, bm);
+				addModelRow(i, bookmarkKey, bm.name, bm.nameI18n, JDs, Location);
+				i++;
+			}
+
+		}
+		catch (std::runtime_error &e)
+		{
+			qDebug() << "[Bookmarks] File format is wrong! Error: " << e.what();
+			return;
 		}
-		QString Location = bookmarkData.value("location").toString();
-		if (!Location.isEmpty())
-			bm.location = Location;
-		QString RA = bookmarkData.value("ra").toString();
-		if (!RA.isEmpty())
-			bm.ra = RA;
-		QString Dec = bookmarkData.value("dec").toString();
-		if (!Dec.isEmpty())
-			bm.dec = Dec;
 
-		bm.isVisibleMarker = bookmarkData.value("isVisibleMarker", false).toBool();
-
-		bookmarksCollection.insert(bookmarkKey, bm);
-		addModelRow(i, bookmarkKey, bm.name, bm.nameI18n, JDs, Location);
-		i++;
 	}
 }
 
@@ -338,7 +447,7 @@ void BookmarksDialog::importBookmarks()
 	QString originalBookmarksFile = bookmarksJsonPath;
 
 	QString filter = "JSON (*.json)";
-	bookmarksJsonPath = QFileDialog::getOpenFileName(0, q_("Import bookmarks"), QDir::homePath(), filter);
+	bookmarksJsonPath = QFileDialog::getOpenFileName(Q_NULLPTR, q_("Import bookmarks"), QDir::homePath(), filter);
 
 	loadBookmarks();
 
@@ -351,24 +460,27 @@ void BookmarksDialog::exportBookmarks()
 	QString originalBookmarksFile = bookmarksJsonPath;
 
 	QString filter = "JSON (*.json)";
-	bookmarksJsonPath = QFileDialog::getSaveFileName(0, q_("Export bookmarks as..."), QDir::homePath() + "/bookmarks.json", filter);
+	bookmarksJsonPath = QFileDialog::getSaveFileName(Q_NULLPTR,
+							 q_("Export bookmarks as..."),
+							 QDir::homePath() + "/bookmarks.json",
+							 filter);
 
 	saveBookmarks();
 
 	bookmarksJsonPath = originalBookmarksFile;
 }
 
-void BookmarksDialog::saveBookmarks()
+void BookmarksDialog::saveBookmarks() const
 {
 	if (bookmarksJsonPath.isEmpty())
 	{
-		qWarning() << "Bookmarks: Error saving bookmarks";
+		qWarning() << "[Bookmarks] Error saving bookmarks";
 		return;
 	}
 	QFile jsonFile(bookmarksJsonPath);
 	if(!jsonFile.open(QFile::WriteOnly|QFile::Text))
 	{
-		qWarning() << "Bookmarks: bookmarks can not be saved. A file can not be open for writing:"
+		qWarning() << "[Bookmarks] bookmarks can not be saved. A file can not be open for writing:"
 			   << QDir::toNativeSeparators(bookmarksJsonPath);
 		return;
 	}
@@ -381,7 +493,7 @@ void BookmarksDialog::saveBookmarks()
 
 	    bookmark sp = i.value();
 	    QVariantMap bm;
-	    bm.insert("name",	sp.name);
+	    bm.insert("name", sp.name);
 	    if (!sp.nameI18n.isEmpty())
 		    bm.insert("nameI18n", sp.nameI18n);
 	    if (!sp.ra.isEmpty())
@@ -394,6 +506,8 @@ void BookmarksDialog::saveBookmarks()
 		    bm.insert("location", sp.location);
 	    if (sp.isVisibleMarker)
 		    bm.insert("isVisibleMarker", sp.isVisibleMarker);
+	    if (sp.fov > 0.0)
+		    bm.insert("fov", sp.fov);
 
 	    bookmarksDataList.insert(i.key(), bm);
 	}
