@@ -17,8 +17,8 @@
  * Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA  02110-1335, USA.
 */
 
-#ifndef _GREATREDSPOTDIALOG_HPP_
-#define _GREATREDSPOTDIALOG_HPP_
+#ifndef GREATREDSPOTDIALOG_HPP
+#define GREATREDSPOTDIALOG_HPP
 
 #include <QObject>
 #include <QDateTime>
@@ -50,4 +50,4 @@ protected:
 
 };
 
-#endif // _GREATREDSPOTDIALOG_HPP_
+#endif // GREATREDSPOTDIALOG_HPP
