@@ -22,6 +22,7 @@
 #include <QDebug>
 
 #include "StelApp.hpp"
+#include "StelGui.hpp"
 #include "StelTranslator.hpp"
 #include "StelActionMgr.hpp"
 #include "ShortcutLineEdit.hpp"
@@ -292,12 +293,14 @@ void ShortcutsDialog::createDialogContent()
 	ui->shortcutsTreeView->header()->setSectionsMovable(false);
 	ui->shortcutsTreeView->sortByColumn(0, Qt::AscendingOrder);
 	
-#ifdef Q_OS_WIN
-	//Kinetic scrolling for tablet pc and pc
-	QList<QWidget *> addscroll;
-	addscroll << ui->shortcutsTreeView;
-	installKineticScrolling(addscroll);
-#endif
+	// Kinetic scrolling
+	kineticScrollingList << ui->shortcutsTreeView;
+	StelGui* gui= dynamic_cast<StelGui*>(StelApp::getInstance().getGui());
+	if (gui)
+	{
+		enableKineticScrolling(gui->getFlagUseKineticScrolling());
+		connect(gui, SIGNAL(flagUseKineticScrollingChanged(bool)), this, SLOT(enableKineticScrolling(bool)));
+	}
 
 	connect(&StelApp::getInstance(), SIGNAL(languageChanged()), this, SLOT(retranslate()));
 	connect(ui->shortcutsTreeView->selectionModel(),
@@ -370,7 +373,7 @@ QStandardItem* ShortcutsDialog::updateGroup(const QString& group)
 	QFont rootFont = groupItem->font();
 	rootFont.setBold(true);
 	// Font size is 14
-	rootFont.setPixelSize(StelApp::getInstance().getBaseFontSize()+1);
+	rootFont.setPixelSize(StelApp::getInstance().getScreenFontSize()+1);
 	groupItem->setFont(rootFont);
 	if (isNew)
 		mainModel->appendRow(groupItem);
@@ -386,7 +389,7 @@ QStandardItem* ShortcutsDialog::updateGroup(const QString& group)
 	return groupItem;
 }
 
-QStandardItem* ShortcutsDialog::findItemByData(QVariant value, int role, int column)
+QStandardItem* ShortcutsDialog::findItemByData(QVariant value, int role, int column) const
 {
 	for (int row = 0; row < mainModel->rowCount(); row++)
 	{
