@@ -17,8 +17,8 @@
  * Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA  02110-1335, USA.
  */
 
-#ifndef _STELGUI_HPP_
-#define _STELGUI_HPP_
+#ifndef STELGUI_HPP
+#define STELGUI_HPP
 
 #ifndef NO_GUI
 
@@ -56,15 +56,23 @@ class StelGui : public QObject, public StelGuiBase
 	Q_PROPERTY(bool visible READ getVisible WRITE setVisible NOTIFY visibleChanged)
 	Q_PROPERTY(bool autoHideHorizontalButtonBar READ getAutoHideHorizontalButtonBar WRITE setAutoHideHorizontalButtonBar NOTIFY autoHideHorizontalButtonBarChanged)
 	Q_PROPERTY(bool autoHideVerticalButtonBar READ getAutoHideVerticalButtonBar WRITE setAutoHideVerticalButtonBar NOTIFY autoHideVerticalButtonBarChanged)
+	Q_PROPERTY(bool flagShowQuitButton READ getFlagShowQuitButton WRITE setFlagShowQuitButton NOTIFY  flagShowQuitButtonChanged)
 	Q_PROPERTY(bool flagShowFlipButtons READ getFlagShowFlipButtons WRITE setFlagShowFlipButtons NOTIFY flagShowFlipButtonsChanged)
 	Q_PROPERTY(bool flagShowNebulaBackgroundButton READ getFlagShowNebulaBackgroundButton WRITE setFlagShowNebulaBackgroundButton NOTIFY flagShowNebulaBackgroundButtonChanged)
 	Q_PROPERTY(bool flagShowDSSButton READ getFlagShowDSSButton WRITE setFlagShowDSSButton NOTIFY  flagShowDSSButtonChanged)
 	Q_PROPERTY(bool flagShowHiPSButton READ getFlagShowHiPSButton WRITE setFlagShowHiPSButton NOTIFY  flagShowHiPSButtonChanged)
+	Q_PROPERTY(bool flagShowGotoSelectedObjectButton READ getFlagShowGotoSelectedObjectButton WRITE setFlagShowGotoSelectedObjectButton NOTIFY flagShowGotoSelectedObjectButtonChanged)
+	Q_PROPERTY(bool flagShowNightmodeButton READ getFlagShowNightmodeButton WRITE setFlagShowNightmodeButton NOTIFY  flagShowNightmodeButtonChanged)
+	Q_PROPERTY(bool flagShowFullscreenButton READ getFlagShowFullscreenButton WRITE setFlagShowFullscreenButton NOTIFY  flagShowFullscreenButtonChanged)
 	Q_PROPERTY(bool flagShowBookmarksButton READ getFlagShowBookmarksButton WRITE setFlagShowBookmarksButton NOTIFY flagShowBookmarksButtonChanged)
 	Q_PROPERTY(bool flagShowICRSGridButton READ getFlagShowICRSGridButton WRITE setFlagShowICRSGridButton NOTIFY flagShowICRSGridButtonChanged)
 	Q_PROPERTY(bool flagShowGalacticGridButton READ getFlagShowGalacticGridButton WRITE setFlagShowGalacticGridButton NOTIFY flagShowGalacticGridButtonChanged )
 	Q_PROPERTY(bool flagShowEclipticGridButton READ getFlagShowEclipticGridButton WRITE setFlagShowEclipticGridButton NOTIFY flagShowEclipticGridButtonChanged )
 	Q_PROPERTY(bool flagShowConstellationBoundariesButton READ getFlagShowConstellationBoundariesButton WRITE setFlagShowConstellationBoundariesButton NOTIFY flagShowConstellationBoundariesButtonChanged )
+	Q_PROPERTY(bool flagShowAsterismLinesButton READ getFlagShowAsterismLinesButton WRITE setFlagShowAsterismLinesButton NOTIFY flagShowAsterismLinesButtonChanged )
+	Q_PROPERTY(bool flagShowAsterismLabelsButton READ getFlagShowAsterismLabelsButton WRITE setFlagShowAsterismLabelsButton NOTIFY flagShowAsterismLabelsButtonChanged )
+	Q_PROPERTY(bool flagUseButtonsBackground   READ getFlagUseButtonsBackground   WRITE setFlagUseButtonsBackground   NOTIFY flagUseButtonsBackgroundChanged)
+	Q_PROPERTY(bool flagUseKineticScrolling READ getFlagUseKineticScrolling WRITE setFlagUseKineticScrolling NOTIFY flagUseKineticScrollingChanged)
 
 public:
 	friend class ViewDialog;
@@ -99,7 +107,7 @@ public:
 	bool initComplete(void) const;
 
 #ifdef ENABLE_SCRIPT_CONSOLE
-	ScriptConsole* getScriptConsole() {return scriptConsole;}
+	ScriptConsole* getScriptConsole() const {return scriptConsole;}
 #endif
 
 	//! Used to force a refreshing of the GUI elements such as the button bars.
@@ -109,7 +117,7 @@ public:
 
 	virtual bool getVisible() const;
 
-	virtual bool getAstroCalcVisible();
+	virtual bool getAstroCalcVisible() const;
 
 	virtual bool isCurrentlyUsed() const;
 	
@@ -117,6 +125,21 @@ public:
 	virtual const StelObject::InfoStringGroup& getInfoTextFilters() const;
 
 public slots:
+	//! Set the state of the flag of usage background for GUI buttons
+	void setFlagUseButtonsBackground(bool b);
+	//! Get the state of the flag of usage background for GUI buttons
+	bool getFlagUseButtonsBackground() const { return flagUseButtonsBackground; }
+
+	//! Set the state of the flag for kinetic scrolling
+	void setFlagUseKineticScrolling(bool b);
+	//! Get the state of the flag for kinetic scrolling
+	bool getFlagUseKineticScrolling() const { return flagUseKineticScrolling; }
+
+	//! Define whether the button for exit should be visible
+	void setFlagShowQuitButton(bool b);
+	//! Get whether the exit button is visible
+	bool getFlagShowQuitButton() const;
+
 	//! Define whether the buttons toggling image flip should be visible
 	void setFlagShowFlipButtons(bool b);
 	//! Get whether the buttons toggling image flip are visible
@@ -137,6 +160,21 @@ public slots:
 	//! Get whether the button toggling HiPS surveys is visible
 	bool getFlagShowHiPSButton() const;
 
+	//! Define whether the button for centering on selected object should be visible. If not, user can still press SPACE to center.
+	void setFlagShowGotoSelectedObjectButton(bool b);
+	//! Get whether the button for centering on selected object is visible
+	bool getFlagShowGotoSelectedObjectButton() const;
+
+	//! Define whether the button toggling nightmode should be visible in addition to the Ctrl+N hotkey.
+	void setFlagShowNightmodeButton(bool b);
+	//! Get whether the button toggling nightmode is visible
+	bool getFlagShowNightmodeButton() const;
+
+	//! Define whether the button toggling fullscreen view should be visible in addition to F11 hotkey.
+	void setFlagShowFullscreenButton(bool b);
+	//! Get whether the button toggling fullscreen view is visible
+	bool getFlagShowFullscreenButton() const;
+
 	//! Define whether the button toggling bookmarks should be visible
 	void setFlagShowBookmarksButton(bool b);
 	//! Get whether the button toggling bookmarks is visible
@@ -162,6 +200,16 @@ public slots:
 	//! Get whether the button toggling constellation boundaries is visible
 	bool getFlagShowConstellationBoundariesButton() const;
 
+	//! Define whether the button toggling asterism lines should be visible
+	void setFlagShowAsterismLinesButton(bool b);
+	//! Get whether the button toggling asterism lines is visible
+	bool getFlagShowAsterismLinesButton() const;
+
+	//! Define whether the button toggling asterism labels should be visible
+	void setFlagShowAsterismLabelsButton(bool b);
+	//! Get whether the button toggling asterism labels is visible
+	bool getFlagShowAsterismLabelsButton() const;
+
 	//! Get the auto-hide status of the horizontal toolbar.
 	bool getAutoHideHorizontalButtonBar() const;
 	//! Set the auto-hide status of the horizontal toolbar.
@@ -198,15 +246,23 @@ signals:
 	void visibleChanged(bool b);
 	void autoHideHorizontalButtonBarChanged(bool b);
 	void autoHideVerticalButtonBarChanged(bool b);
+	void flagUseButtonsBackgroundChanged(bool b);
+	void flagUseKineticScrollingChanged(bool b);
+	void flagShowQuitButtonChanged(bool b);
 	void flagShowFlipButtonsChanged(bool b);
 	void flagShowNebulaBackgroundButtonChanged(bool b);
 	void flagShowDSSButtonChanged(bool b);
 	void flagShowHiPSButtonChanged(bool b);
+	void flagShowGotoSelectedObjectButtonChanged(bool b);
+	void flagShowNightmodeButtonChanged(bool b);
+	void flagShowFullscreenButtonChanged(bool b);
 	void flagShowBookmarksButtonChanged(bool b);
 	void flagShowICRSGridButtonChanged(bool b);
 	void flagShowGalacticGridButtonChanged(bool b);
 	void flagShowEclipticGridButtonChanged(bool b);
 	void flagShowConstellationBoundariesButtonChanged(bool b);
+	void flagShowAsterismLinesButtonChanged(bool b);
+	void flagShowAsterismLabelsButtonChanged(bool b);
 
 private slots:
 	void reloadStyle();
@@ -222,17 +278,24 @@ private slots:
 
 private:
 	//! convenience method to find an action in the StelActionMgr.
-	StelAction* getAction(const QString& actionName);
+	StelAction* getAction(const QString& actionName) const;
 
 	QGraphicsWidget* topLevelGraphicsWidget;
 
 	class SkyGui* skyGui;
 
+	bool flagUseButtonsBackground;
+	bool flagUseKineticScrolling;
+
 	StelButton* buttonTimeRewind;
 	StelButton* buttonTimeRealTimeSpeed;
 	StelButton* buttonTimeCurrent;
 	StelButton* buttonTimeForward;
 
+	bool flagShowQuitButton;
+	StelButton* buttonQuit;
+
+	bool flagShowGotoSelectedObjectButton;
 	StelButton* buttonGotoSelectedObject;
 
 	LocationDialog* locationDialog;
@@ -261,6 +324,12 @@ private:
 	bool flagShowHiPSButton;
 	StelButton* btShowHiPS;
 
+	bool flagShowNightmodeButton;
+	StelButton* buttonNightmode;
+
+	bool flagShowFullscreenButton;
+	StelButton* buttonFullscreen;
+
 	bool flagShowBookmarksButton;
 	StelButton* btShowBookmarks;
 
@@ -276,6 +345,12 @@ private:
 	bool flagShowConstellationBoundariesButton;
 	StelButton* btShowConstellationBoundaries;
 
+	bool flagShowAsterismLinesButton;
+	StelButton* btShowAsterismLines;
+
+	bool flagShowAsterismLabelsButton;
+	StelButton* btShowAsterismLabels;
+
 	bool initDone;
 
 	QSizeF savedProgressBarSize;
@@ -317,4 +392,4 @@ private:
 
 #endif
 
-#endif // _STELGUI_HPP_
+#endif // STELGUI_HPP
