@@ -14,11 +14,11 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA  02110-1335, USA.
  */
 
-#ifndef _STELSTYLE_HPP_
-#define _STELSTYLE_HPP_
+#ifndef STELSTYLE_HPP
+#define STELSTYLE_HPP
 
 #include <QString>
 #include <QByteArray>
@@ -38,4 +38,4 @@ public:
 	QString confSectionName;
 };
 
-#endif // _STELSTYLE_HPP_
+#endif // STELSTYLE_HPP
