@@ -17,8 +17,8 @@
  * Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA  02110-1335, USA.
 */
 
-#ifndef _VIEWDIALOG_HPP_
-#define _VIEWDIALOG_HPP_
+#ifndef VIEWDIALOG_HPP
+#define VIEWDIALOG_HPP
 
 #include "StelDialog.hpp"
 
@@ -95,51 +95,6 @@ private slots:
 	void updateHips();
 	void hipsListItemChanged(QListWidgetItem* item);
 
-	void askEclipticJ2000GridColor();
-	void askEclipticGridColor();
-	void askEquatorJ2000GridColor();
-	void askEquatorGridColor();
-	void askGalacticGridColor();
-	void askSupergalacticGridColor();
-	void askAzimuthalGridColor();
-	void askEclipticLineJ2000Color();
-	void askEclipticLineColor();
-	void askEquatorLineJ2000Color();
-	void askEquatorLineColor();
-	void askGalacticEquatorLineColor();
-	void askSupergalacticEquatorLineColor();
-	void askLongitudeLineColor();
-	void askHorizonLineColor();
-	void askColureLinesColor();
-	void askCircumpolarCirclesColor();
-	void askPrecessionCirclesColor();
-	void askPrimeVerticalLineColor();
-	void askMeridianLineColor();
-	void askCardinalPointsColor();
-	void askCelestialJ2000PolesColor();
-	void askCelestialPolesColor();
-	void askZenithNadirColor();
-	void askEclipticJ2000PolesColor();
-	void askEclipticPolesColor();
-	void askGalacticPolesColor();
-	void askSupergalacticPolesColor();
-	void askEquinoxJ2000PointsColor();
-	void askEquinoxPointsColor();
-	void askSolsticeJ2000PointsColor();
-	void askSolsticePointsColor();
-	// constellations colors
-	void askConstellationLabelsColor();
-	void askConstellationLinesColor();
-	void askConstellationBoundariesColor();
-	// asterisms colors
-	void askAsterismLabelsColor();
-	void askAsterismLinesColor();
-	void askRayHelpersColor();
-	// nomenclature color
-	void askPlanetNomenclatureColor();	
-	void askPlanetLabelsColor();
-	void askPlanetTrailsColor();
-
 private:
 	void connectGroupBox(class QGroupBox* groupBox, const QString& actionId);
 	void updateSkyCultureText();
@@ -147,8 +102,6 @@ private:
 	//! @todo Limit the width to the width of the screen *available to the window*.
 	void updateTabBarListWidgetWidth();
 
-	void colorButton(QToolButton *toolButton, QString propName);
-
 	AddRemoveLandscapesDialog * addRemoveLandscapesDialog;
 	AtmosphereDialog * atmosphereDialog;
 	GreatRedSpotDialog * greatRedSpotDialog;
@@ -156,4 +109,4 @@ private:
 	ConfigureOrbitColorsDialog * configureOrbitColorsDialog;
 };
 
-#endif // _VIEWDIALOG_HPP_
+#endif // _VIEWDIALOG_HPP
