@@ -17,8 +17,8 @@
  * Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA  02110-1335, USA.
  */
 
-#ifndef _TESTDATES_HPP_
-#define _TESTDATES_HPP_
+#ifndef TESTDATES_HPP
+#define TESTDATES_HPP
 
 #include <QObject>
 #include <QTest>
@@ -41,5 +41,5 @@ private:
 	void testJulianDaysRange(int jd_first, int jd_last);
 };
 
-#endif // _TESTDATES_HPP_
+#endif // _TESTDATES_HPP
 
