@@ -17,11 +17,11 @@
  * Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA  02110-1335, USA.
  */
 
-#ifndef _TESTSTELVERTEXARRAY_HPP_
-#define _TESTSTELVERTEXARRAY_HPP_
+#ifndef TESTSTELVERTEXARRAY_HPP
+#define TESTSTELVERTEXARRAY_HPP
 
 #include <QObject>
-#include <QtTest>
+#include <QTest>
 
 #include "StelVertexArray.hpp"
 
@@ -37,4 +37,4 @@ private:
 	StelVertexArray array;
 };
 
-#endif // _TESTSTELVERTEXARRAY_HPP_
+#endif // _TESTSTELVERTEXARRAY_HPP
